#!/bin/bash

#****b* Installation/db_update_blz.sh
# NAME
# bash/db-update_blz.sh
#   Das Script installiert die die Bankdaten in die Tabelle
#   key_banken.
#
#   Die Daten stammen von der DEUTSCHEN BUNDESBANK
#   http://www.bundesbank.de
# BESTANDTEILE
# /etc/uverein/config
#   hier werden folgende Informationen abgelegt:
#     [BLZ.DE.STAND]   Stand der Bankleitzahlendatei = gueltig ab
#     [BLZ.DE.INSERT]  YES = Daten einbinden
#                      NO  = Daten nicht einbinden
# include/uverein.config
#   hierbei handelt es sich um einen Link auf /etc/uverein/config
#
# sql/blz-de.sql
#   alle deutschen Bankleitzahlen als TAB-getrennte Datei
#   Spalte 1  A = aktuell
#             D = geloescht
#   Spalte 2  BIC / SWIFT der Bank
#   Spalte 3  Bankleitzahl
#   Spalte 4  Spalte 1 = A: Bezeichnung der Bank
#             Spalte 1 = D: Neue Bankleitzahl der Bank
#
# sql/blz-de.diff.sql
#   alle Aenderungen der Bankdaten seit der letzten Aktualisierung
#   als TAB-getrennte Datei
#   Die Spalten haben die gleiche Bedeutung wie bei sql-de.sql
# BUGS
#   keine bekannt
#****

CONFIG=$(dirname $0)/../include/uverein.config
touch ${CONFIG}

SQL=$(mktemp)
VEREINE=$(mktemp)
RUN=$(mktemp)

BLZ_DE=blz-de.diff.sql
BLZAKTUELL=$(grep "\[BLZ\.DE\.STAND\]" ${CONFIG} | cut -f2)
BLZDATEI=$(grep "\[INFO\]" $(dirname $0)/../sql/${BLZ_DE} | cut -f2)
BLZINSERT=$(grep "\[BLZ\.DE\.INSERT\]" ${CONFIG} | cut -f2)

if [ "${BLZAKTUELL}" != "${BLZDATEI}" ]; then
  if [ "${BLZINSERT}" = "" ]; then
    BLZ_DE=blz-de.sql 
    dialog --keep-tite --stdout --yesno "insert german banking-info" 6 65
    if [ $? == 0 ]; then
      BLZINSERT="YES"
    else
      BLZINSERT="NO"
    fi
  fi
if [ "${BLZINSERT}" = "YES" ]; then 
  echo "INSERT GERMAN BANKING-INFO - takes a while ...."
  #
  # Vereine auslesen
  #
  psql -d udb.uverein -q -t -c "SELECT kurzname FROM vereine" | sed "s/ //g" >${VEREINE}

  OLDIFS=${IFS}
  IFS="
"
  for X in $(cat $(dirname $0)/../sql/${BLZ_DE} | grep -v "\[INFO\]")
  do
    AKTION=$(echo $X | cut -f1)
    BIC=$(echo $X | cut -f2)  # BIC oder SWIFT der Bank
    ALT=$(echo $X | cut -f3)  # Bankleitzahl (BLZ)
    NEU=$(echo $X | cut -f4-) # Wenn BLZ geloescht wird neue BLZ ansonsten Name der Bank
    if [ "${AKTION}" = "D" ]; then
      echo "UPDATE vereine SET blz='${NEU}' WHERE blz='${ALT}';"                              >>${SQL}
      for V in $(cat ${VEREINE}) 
      do
        echo "UPDATE ${V}_einzug SET blz='${NEU}' WHERE blz='${ALT}';"                        >>${SQL}
      done
      echo "DELETE FROM key_banken WHERE blz='${ALT}';"                                       >>${SQL}
    else
      echo    "UPDATE key_banken SET bank=rtrim('${BIC}: ${NEU}',' ') WHERE blz='${ALT}';"    >>${SQL}
      printf  "INSERT INTO key_banken (blz,bank) SELECT '${ALT}',rtrim('${BIC}: ${NEU}',' ')" >>${SQL}
      echo    " WHERE NOT EXISTS (SELECT * FROM key_banken WHERE key_banken.blz='${ALT}');"   >>${SQL}
      echo    "UPDATE vereine SET bank='${BIC}: ${NEU}' WHERE blz='${ALT}';"                  >>${SQL}
    fi
  done
  IFS=${OLDIFS}
  for SCHEMA in public testing
  do
    echo "SET search_path TO ${SCHEMA};"  >${RUN}
    cat ${SQL}                           >>${RUN}
    psql -q --file ${RUN} --dbname udb.uverein 
  done
fi
fi

grep -v "\[BLZ\.DE\.STAND\]" ${CONFIG} | grep -v "\[BLZ\.DE\.INSERT\]" >${RUN}
echo "[BLZ.DE.STAND]	${BLZDATEI}"     >>${RUN}
echo "[BLZ.DE.INSERT]	${BLZINSERT}" >>${RUN}
cp ${RUN} ${CONFIG}

rm ${VEREINE} ${SQL} ${RUN}
