<?php
//****h* Allgemein/base.inc
// NAME
//   base.inc
//   Dieses Modul muss in jede PHP-Datei direkt oder indirekt eingebunden werden
//   Es werden die globalen Einstellungen fuer das Projekt vorgenommen
// AUTOR
//   Uwe Schied

// ABHAENGIG VON
//   base-initial.inc       (Projekteinstellungen)
//   database.inc           (Datenbank-Klasse)
//   funktionen.php         (Funktionen-Sammlung)
//   klasse/formular.inc    (Formularverwaltung)

// DEFINITION
//   Variable / Konstante    Informationen
//   --------------------------------------------------------------------------
//   AKT_YEAR                aus Superglobals ausgelesen
//
//   AUSWAHL                 aus Superglobals ausgelesen
//
//   EDIT_LANG               aus Superglobals ausgelesen
//
//   SPRACHE                 aktuelle Sprache
//
//   UVEREIN_DB              Datenbankzugriff ueber die Klasse cl_database
//
//   VEREIN_CHANGED          aus Superglobals ausgelesen
//
//   VEREIN_NAME             Name des aktuellen Vereins
//
//   VIRTUALKONTO            Array mit symbolischen Werten, fuer andere Module.
//                           KEY               Inhalt
//                           ..................................................
//                           Konten und Kontenklassen:
//                             BEITRAG         Beitragskonto
//                             UST             Konto fuer die Vorsteuer
//                             FINANZ          Finanzkonten aus bu_klasse
//                             UEBERTRAG       Konto fuer den Uebertrag
//                             SCHWEBE         Schwebekonto
//                           In der Datenbank erfasste Texte:
//                             BEITRAG1        1. Beitragserinnerung
//                             BEITRAG2        2. Beitragserinnerung
//                             BEITRAG3        3. Beitragserinnerung
//                             BEITRAGLEV      Lastschrift nicht eingeloest
//
//   FORM                    Formular
//   SPECIAL_CALL            Klasse cl_special 
//***

include_once (dirname (__FILE__) . "/base-initial.inc");
include_once (dirname (__FILE__) . "/klassen/uverein-database.inc");
include_once (dirname (__FILE__) . "/klassen/formular.inc");
include_once (dirname (__FILE__) . "/funktionen.php");
include_once (dirname (__FILE__) . "/klassen/special.inc");

//
// Formular-Klasse initialisieren
//
$FORM = new cl_formular();

// 
// Sonderfaelle initialisieren = Klasse cl_special
//
$SPECIAL_CALL = new cl_special ();

// --------------------------------------------------------
// Kontendefinitionen fuer Buchhaltung bzw. Beitragsverwaltung
// --------------------------------------------------------
$VIRTUALKONTO              = array ("BEITRAG"=>"BEITRAG");  // Beitragskonto
$VIRTUALKONTO["UST"]       = "VORSTEUER";                   // Vorsteuer
$VIRTUALKONTO["FINANZ"]    = "FINANZKONTO";                 // Finanzkonten
$VIRTUALKONTO["UEBERTRAG"] = "UEBERTRAG";                   // interne Buchungen
$VIRTUALKONTO["SCHWEBE"]   = "SCHWEBEKONTO";                // Schwebebuchungen

// --------------------------------------------------------
// Definitionen zur Beitragserinnerung
// --------------------------------------------------------
$VIRTUALKONTO["BEITRAG1"] = "BEITRAG_1";         // 1. Erinnerung
$VIRTUALKONTO["BEITRAG2"] = "BEITRAG_2";         // 2. Erinnerung
$VIRTUALKONTO["BEITRAG3"] = "BEITRAG_3";         // 3. Erinnerung
$VIRTUALKONTO["BEITRAGLEV"] = "BEITRAG_LEV";     // Lastschrift nicht eingeloest

// --------------------------------------------------------
// Basiseinstellungen des Programms
// --------------------------------------------------------
// Kurzname des zuletzt genutzten Vereins
cookie_base ("VEREIN","muster",$FORM->returnglobal("SET_VEREIN"));
$VEREIN_NAME = cookie_lesen ("VEREIN");
// Sprache
cookie_base ("LANGUAGE","DE",$FORM->returnglobal("SET_LANGUAGE"));
$SPRACHE = cookie_lesen ("LANGUAGE");
$SPRACHE = (strlen($SPRACHE) == 0) ? "DE" : $SPRACHE;

// --------------------------------------------------------
// Jahr einstellen
// --------------------------------------------------------
cookie_base ("AKT_YEAR",date("Y"),$FORM->returnglobal("AKT_YEAR"));
$AKT_YEAR  = cookie_lesen ("AKT_YEAR");

// --------------------------------------------------------
// Datenbank oeffnen
// --------------------------------------------------------
$UVEREIN_DB = new cl_uverein_database ($DB_NAME,$DB_SCHEMA);
if ($UVEREIN_DB->ERRORCODE > 0)   // Fehler aufgetreten
{
  echo "<HR>Connect to database closed with ERROR:<B>".
       $UVEREIN_DB->error_text().
       "</B><HR>";
  exit(1);
}
$UVEREIN_DB->sql_befehl ("SET DATESTYLE='".i4l("language_datestyle")."'");
//$UVEREIN_DB->TESTMODE = true;

// --------------------------------------------------------
// Feature-Request 3054813 offene Überweisungen verwalten
// --------------------------------------------------------
$UVEREIN_DB->sql_befehl ("SELECT * FROM bu_belege WHERE idx=0");
$SPALTENTEST = $UVEREIN_DB->fieldnames();
// Neue Spalte bereits vorhanden - wenn nein anlegen
if (! in_array("erledigt", $SPALTENTEST))
{
  $UVEREIN_DB->sql_befehl ("ALTER TABLE bu_belege ADD erledigt BOOLEAN NOT NULL DEFAULT FALSE");
  // alle Einträge auf erledigt setzen
  $UVEREIN_DB->sql_befehl ("UPDATE bu_belege SET erledigt=TRUE");
}

// --------------------------------------------------------
// Aktuelle Daten eintragen
// --------------------------------------------------------
$UVEREIN_DB->set_verein ($VEREIN_NAME);
$UVEREIN_DB->set_jahr   ($AKT_YEAR);

// --------------------------------------------------------
// Vordefinierte Variablen aus SUPERGLOBALS auslesen
// --------------------------------------------------------
$AUSWAHL        = $FORM->returnglobal ("AUSWAHL");
$EDIT_LANG      = $FORM->returnglobal ("EDIT_LANG");
$VEREIN_CHANGED = $FORM->returnglobal ("VEREIN_CHANGED");

//****M* base.inc/update
// DEFINITION
//   PROJEKT_UPDATE_1705274    bu_kst um Jahr ergaenzen     in Arbeit
define ('PROJEKT_UPDATE_1705274',false);
//   PROJEKT_UPDATE_1424032    Tipp einblenden              in Arbeit
define ('PROJEKT_UPDATE_1424032',false);

// FUNCTION
//   use_update ($n)
//     gibt true zurueck, wenn das Update benutzt werden kann
//     oder der Testmodus aktiv ist.
function use_update ($n)
{
  global $PROJECT_TEST_MODE;
  return (($PROJECT_TEST_MODE == "YES") ? true : $n);
}
//***

// --------------------------------------------------------
// Daten fuer die Programmhilfe einbinden
// --------------------------------------------------------
include_once (dirname (__FILE__) . "/../doc/html/helpindex_de.inc"); 

// Login-Abfrage einbinden
include_once "login.php";

?>
