<?php

//****h* Datenbank-Klasse/database.inc
// KLASSE
//   cl_database
//   Klasse fuer den Zugriff auf eine Postgres-Datenbank
// HISTORIE
//   12.12.2009 Fehlercodes ausgelager in database-errorcode.inc
//   08.08.2009 Schema beim oeffnen der Datenbank aktivieren
//   17.02.2009 Schema eingebunden
//   15.12.2007 Klasse erstellt
// BUGS
//   keine bekannt
//****

include_once (dirname (__FILE__) . "/database-errorcode.inc"); // Fehlercodes

// NOTES
// --------------------------------------------------------
//****
class cl_database
{
  var $DATENBANK;             // Datenbank-Resource
  var $SCHEMA;                // Datenbank-Schema
  var $DBNAME;                // Name der Datenbank
  var $ERRORCODE;             // Fehlercode
  var $ERRORTEXT;             // Array mit Fehlertext
  var $qu;                    // Zeiger auf Query
//****v* database.inc/TESTMODE
// VARIABLE
//   TESTMODE
//   Wenn diese Variable auf true gesetzt ist, werden zu jeder Daten-
//   bankaktion Meldungen mit den Aufrufparametern und den Rueckgabe-
//   werten ausgegeben.
//
//   Voreinstellung = false
//
//   Die Variable kann ausserhalb der Klasse geaendert werden und
//   wirkt sich nur innerhalb der Klasse aus.
  var $TESTMODE;
//****

//****f* database.inc/error_name (Fehler-Nr., Fehlertext)
// FUNCTION
//   error_name ($key, $inhalt)
//     $key     Fehlercode lt. untenstehender Tabelle
//     $inhalt  Text, der ausgegeben werden soll
//
//   Mit dieser Funktion koennen Fehlermeldungen eingetragen werden. Die
//   folgenden Fehlercodes sind vorhanden und koennen geaendert werden:
//
//   $key                        ! $inhalt
//   ----------------------------!-------------------------------------
//   CL_DATABASE_OK              ! OK
//   CL_DATABASE_ERROR_CANTOPEN  ! Can't open Database
//   CL_DATABASE_ERROR_SQL       ! Error while executing SQL-query
//   CL_DATABASE_ERROR_UNKNOWN   ! Unknown Error
//
//   Fehler-Array wird innerhalb der Klasse aktualisiert
//
// BEISPIEL
//   $datenbank->error_name (CL_DATABASE_OK,"Alles OK");
// ERGEBNIS
//   Die Funktion gibt kein Ergebnis zurueck
//****
  function error_name ($key, $inhalt) // Textmeldung eintragen
  {
    $this->ERRORTEXT[$key] = $inhalt;
  }

//****f* database.inc/error_text ()
// FUNCTION
//   error_text
//
//   Diese Funktion gibt des Status der letzten Aktion zurueck. Ausgegeben
//   wird der durch die Funktion error_name voreingestellte Text
// BEISPIEL
//   echo $datenbank->error_text();
// ERGEBNIS
//   Zeichenkette mit der Fehlermeldung
//****
  function error_text ()
  {
    $x = "";
    $i = ($this->ERRORCODE > CL_DATABASE_OK) ? $this->ERRORCODE : CL_DATABASE_OK;
    $i = ($i <= CL_DATABASE_MAX_ERROR) ? $i : CL_DATABASE_MAX_ERROR;
    return (pg_last_error().": ".$this->ERRORTEXT[$i]);
  }

//****f* database.inc/testmode (Fehlerinformation)
// FUNCTION
//   testmode ($info)
//
//   Meldungen, die ausgegeben werden, wenn TESTMODE = true
//
//   Die Funktion wird nur innerhalb der Klasse verwandt und soll
//   von ausserhalb nicht aufgerufen werden.
//****
  function testmode ($info)
  {
    if ($this->TESTMODE)
    {
      echo "<HR>DATABASE-CONNECTION-STATUS: ".pg_connection_status($this->DATENBANK).
           "<BR>SCHEMA:  $this->SCHEMA".
           "<HR>$info".
           "<BR>RETURN: ".$this->error_text().
           "<BR>LINES:  ".@pg_num_rows($this->qu).
           "<BR>";
    }
  }

//****f* database.inc/sql_befehl (Befehl)
// FUNCTION
//   sql_befehl ($befehl)
//     $befehl    SQL-Befehl, der ausgefuehrt werden soll
//
//   Die Funktion schickt den uebergebenen SQL-Befehl direkt an die Datenbank
// ERGEBNIS
//   Es wird ein Zeiger auf die Antwort zurueck geliefert
// BEISPIEL
//   $qu = $datenbank->sql_befehl("SELECT * FROM belege");
//   $i = 0; while ($i < $datenbank->sql_lines($qu))
//   {
//     $data = $datenbank->sql_lines($qu);
//     echo "$data->nr $data->datum $data->text <BR>";
//     $i++;
//   }
//****
  function sql_befehl ($befehl)
  {
    $this->ERRORCODE = CL_DATABASE_OK;
    $this->qu = @pg_query ($this->DATENBANK,"$befehl");
    if (!$this->qu) $this->ERRORCODE = CL_DATABASE_ERROR_SQL;
    $this->testmode ($befehl);
    return ($this->qu);
  }

//****f* database.inc/sql_lines (Antwortzeiger)
// FUNCTION
//   sql_lines ([$qu])
//     $qu    optionale Angabe des Antwortzeigers
//
//   Die Funktion liefert die Anzahl der Zeilen zur letzten oder optional
//   der durch den Antwortzeiger definierten SQL-Abfrage zurueck.
// ERGEBNIS
//   Der Rueckgabewert ist eine Zahl >= 0
// BEISPIEL
//   $qu = $datenbank->sql_befehl("SELECT * FROM belege");
//   echo "Die Abfrage hat ";
//   echo $datenbank->sql_lines();
//   echo " Ergebnisse gebracht.";
//****
  function sql_lines ($qu = NULL)
  {
    $query = ($qu == NULL) ? $this->qu : $qu;
    if ($query) $x = @pg_num_rows ($query);
    else        $x = 0;
    return ($x);
  }

//****f* database.inc/sql_fields (Antwortzeiger)
// FUNCTION
//   sql_fields ([$qu])
//     $qu    optionale Angabe des Antwortzeigers
//
//   Die Funktion liefert die Anzahl der Spalten zur letzten oder optional
//   der durch den Antwortzeiger definierten SQL-Abfrage zurueck.
// ERGEBNIS
//   Der Rueckgabewert ist eine Zahl >= 0
// BEISPIEL
//   $qu = $datenbank->sql_befehl("SELECT * FROM belege");
//   echo "Die Abfrage hat ";
//   echo $datenbank->sql_fields();
//   echo " Spalten zurueck gegeben.";
//****
  function sql_fields ($qu = NULL)
  {
    $query = ($qu == NULL) ? $this->qu : $qu;
    if ($query) $x = @pg_num_fields ($query);
    else        $x = 0;
    return ($x);
  }

//****f* database.inc/fieldnames (Antwortzeiger)
// FUNCTION
//   fieldnames ([$qu])
//     $qu    optionale Angabe des Antwortzeigers
//
//   Die Funktion liefert ein Array mit den Spaltenueberschriften = Feld-
//   namen zur letzten oder optional der durch den Antwortzeiger definierten
//   SQL-Abfrage zurueck.
// ERGEBNIS
//   Der Rueckgabewert ist ein Array mit den Feldnamen. Wenn die letzte An-
//   frage keine Felder lieferte wird ein leerer String zurueck geliefert.
// BEISPIEL
//   $qu = $datenbank->sql_befehl("SELECT * FROM belege");
//   $FELDER = $datenbank->fieldnames();
//   foreach ($FELDER as $key => $inhalt)
//   {
//     echo "$key = $inhalt <BR>";
//   }
//****
  function fieldnames ($qu = NULL)
  {
    $query = ($qu == NULL) ? $this->qu : $qu;
    $max = $this->sql_fields($query);
    if ($max > 0)
    {
      $i = 0;
      while ($i < $max)
      {
        $ARR[$i] = @pg_field_name($query,$i);
        $i++;
      }
    }
    else $ARR[0] = "";
    return ($ARR);
  }

//****f* database.inc/sql_line (Zeilen-Nr, Antwortzeiger)
// FUNCTION
//   sql_line ($nr, [$qu])
//     $nr    Zeilen-Nr. die geholt werden soll
//     $qu    optionale Angabe des Antwortzeigers
//
//   Die Funktion gibt die gewaehlte Antwortzeile zur SQL-Abfrage zurueck. $nr
//   wird geprueft und nur gültige Zeilen ausgewählt.
// ERGEBNIS
//   Es wird ein Array mit der gewuenschten Zeile zurueck gegeben.
//     * wenn $nr < 0 wird die erste Zeile ausgegeben
//     * wenn $nr > Anzahl der Spalten, wird die letzte Zeile ausgeben
// BEISPIEL
//   $qu = $datenbank->sql_befehl("SELECT * FROM belege");
//   $data = $datenbank->sql_line(0,$qu);
//   echo "$data->nr $data->datum $data->text <BR>";
//****
  function sql_line ($nr,$qu = NULL)
  {
    $query = ($qu == NULL) ? $this->qu : $qu;
    $nr = ($nr < 0) ? 0 : $nr;
    $nr = ($nr > $this->sql_lines($query))
        ? $this->sql_lines($query) - 1
        : $nr;
    if ($query) $data = @pg_fetch_object ($query,$nr);
    else        $data = "";
    return ($data);
  }

//****f* database.inc/result_array (Antwortzeiger)
// FUNCTION
//   result_array ([$qu])
//     $qu    optionale Angabe des Antwortzeigers
//
//   Array mit dem Resultat einer SQL-Abfrage
// ERGEBNIS
//   Die Funktion gibt das Ergebnis der letzten oder der durch den Antwort-
//   zeiger uebergebenen Anfrage als zweidiminensionales Array zurueck.
//
//   Die Adressierung im Array geschieht durch Angabe von Zeilen und Spalten-
//   Nr. oder alternativ durch Zeilen-Nr. und Feldname.
//
//   Wenn die gewuenschte Abfrage kein Ergebnis liefert ist die Rueckgabe
//   nicht definiert.
// BEISPIEL
//   $qu = $datenbank->sql_befehl("SELECT * FROM belege");
//   $data = $datenbank->result_array();
//   echo "In Feld 0 der Zeile 0 steht ".$data[0][0];
//   echo "Im Feld kontonr der Zeile 0 steht ".$data[0]["kontonr"];
//****
  function result_array ($qu = NULL)
  {
    $qu = ($qu == NULL) ? $this->qu : $qu;
    return (@pg_fetch_array($qu));
  }

//****f* database.inc/sql_abfrage (Tabelle, WHERE-Abfrage, Sortierung, Gruppierung)
// FUNCTION
//   sql_abfrage ($tabelle, $where , [[$order],$group])
//     $tabelle  Welche Datenbank-Tabelle soll abgefragt werden?
//     $where    Abfrage
//     $order    Optionale Sortierung der Rueckgabe
//     $group    Optionale Gruppierung. Wenn hier Angaben gemacht werden, muss
//               beachtet werden, dass alle Felder abgefragt werden - im
//               Normalfall bleibt dieses Feld daher leer.
//
//   Die Funktion setzt aus den uebergebenene Daten einen SQL-Befehl zusammen
//   und gibt diesen an die Datenbank weiter.
// ERGEBNIS
//   Es wird ein Zeiger auf die Antwort zurueck geliefert.
// BEISPIEL
//   $qu = $datenbank->sql_abfrage("belege","nr>10");
//   // gibt alle Belege mit einer Beleg-Nr. > 10 zurueck
//   $i = 0; while ($i < $datenbank->sql_lines())
//   {
//     $data = $datenbank->sql_line($i);
//     echo "$data->nr $data->datum $data->text <BR>";
//     $i++;
//   }
//****
  function sql_abfrage ($tabelle, $where, $order = "", $group = "")
  {
    $WHERE = (empty($where)) ? "" : "WHERE " . $where;
    $ORDER = ($order == "") ? "" : "ORDER BY " . $order;
    $GROUP = ($group == "") ? "" : "GROUP BY " . $group;
    $this->sql_befehl ("SELECT * FROM $tabelle $WHERE $ORDER $GROUP");
  }

//****f* database.inc/sql_1_value (Tabelle, abzuholendes Feld, WHERE-Abfrage)
// FUNCTION
//   sql_1_value ($tabelle, $wert, $where)
//     $tabelle  Welche Datenbank-Tabelle soll abgefragt werden?
//     $wert     Welches Feld soll geholt werden?
//     $where    Abfrage
//
//   Die Funktion holt einen Wert aus der Datenbank. Die WHERE-Formulierung
//   sollte daher ganz genau ueberdacht werden.
// ERGEBNIS
//   Es wird der Inhalt des gesuchten Feldes zurueck gegeben. Wenn WHERE kein
//   Ergebnis lieferte, wird ein leerer String zurueck gegeben.
// BEISPIEL
//   $nr = $datenbank->sql_1_value("belege","max(nr) + 1","");
//   // gibt die naechste Beleg-Nr. zurueck
//   echo "Die naechste Beleg-Nr. ist $nr";
//****
  function sql_1_value ($tabelle, $wert, $where)
  {
    $qu = $this->qu;
    $WHERE = ($where != "") ? " WHERE $where" : "";
    $this->sql_befehl ("SELECT $wert AS abfrage FROM $tabelle $WHERE");
    $data = $this->sql_line(0);
    $this->qu = $qu;
    return ((empty($data->abfrage)) ? "" : $data->abfrage);
  }

//****f* database.inc/sql_insert (Tabelle, welche Felder, Eintraege)
// FUNCTION
//   sql_insert ($tabelle, $was , $inhalt)
//     $tabelle  Datenbank-Tabelle in die eingetragen werden soll
//     $was      Welche Felder werden eingetragen?
//     $inhalt   Die VALUES, die eingetragen werden
//
//   Die Funktion fuegt eine neue Zeile in die Datenbank ein. Die Anzahl der
//   Felder muss mit den in $inhalt angegebenen Feldern uebereinstimmen. Die
//   Funktion prueft nicht ob die Zeile tatsaechlich eingefuegt werden kann.
//   Konnte die Zeile nicht eingefuegt werden, ist der Errorcode auf
//   CL_DATABASE_ERROR_SQL gesetzt.
// ERGEBNIS
//   Die Funktion gibt kein Resultat zurueck.
// BEISPIEL
//   $datenbank->sql_insert ("belege","nr,datum,betrag","'21','14.02.2009','100.98');
//
//   Ob ein Fehler aufgetreten ist, kann ueber den Errorcode abgefragt werden.
//
//   if ($datenbank->ERRORCODE != CL_DATABASE_OK)
//     echo $datenbank->error_text();
//****
  function sql_insert ($tabelle, $was, $inhalt)
  {
    $this->sql_befehl ("INSERT INTO $tabelle ($was) $inhalt");
  }

//****f* database.inc/sql_update (Tabelle, Neue Einraege, WHERE-Abfrage)
// FUNCTION
//   sql_update ($tabelle, $set , [$condition])
//     $tabelle   Datenbank-Tabelle, die geaendert werden soll
//     $set       neue Eintraege
//     $condition Optionale WHERE-Angabe
//
//   Mit dieser Funktion koennen ein oder mehrere Felder mit geaenderten Werten
//   ueberschrieben werden. Die Funktion prueft nicht ob die Aenderung tat-
//   saechlich durchgefuehrt werden kann. Konnte keine Aenderung erfolgen, ist
//   der Errorcode auf CL_DATABASE_ERROR_SQL gesetzt
// ERGEBNIS
//   Die Funktion gibt kein Resultat zurueck.
// BEISPIEL
//   $datenbank->sql_update ("belege","nr='10',"nr='99');
//
//   Ob ein Fehler aufgetreten ist, kann ueber den Errorcode abgefragt werden.
//
//   if ($datenbank->ERRORCODE != CL_DATABASE_OK)
//****
  function sql_update ($tabelle, $set, $condition = "")
  {
    $condition = ($condition=="") ? "" : " WHERE " . $condition;
    $this->sql_befehl ("UPDATE $tabelle SET $set $condition");
  }

//****f* database.inc/datenbank_oeffnen ()
// FUNCTION
//   datenbank_oeffnen ()
//
//   Diese Funktion wird nur klassenintern benutzt und oeffnet die Datenbank.
// ERGEBNIS
//   Klasseninterne Datenbankvariablen werden gesetzt.
//****
  function datenbank_oeffnen ()
  {
    $this->DATENBANK = @pg_connect ("dbname='".$this->DBNAME."'");
    $this->ERRORCODE = ($this->DATENBANK === false)
                     ? CL_DATABASE_ERROR_CANTOPEN
                     : CL_DATABASE_OK;
    if ($this->ERRORCODE === CL_DATABASE_OK)
    {
      $stat = @pg_connection_status($this->DATENBANK);
      $this->ERRORCODE = (!$this->DATENBANK)
                       ? CL_DATABASE_ERROR_CANTOPEN
                       : (($stat === PGSQL_CONNECTION_OK)
                         ? CL_DATABASE_OK
                         : CL_DATABASE_ERROR_UNKNOWN);
    }
    $this->testmode ("pg_connect(\"dbname='\".$this->DBNAME.\"'\")");
    @pg_query ($this->DATENBANK, "SET search_path TO $this->SCHEMA");
  }

//****f* database.inc/cl_database (Datenbank, Datenbank-Schema)
// DEFINITION
//   cl_database ($name, $schema)
//   Konstruktor der Klasse. Die Initialisierung erfolgt durch Uebergabe des
//   Datenbanknamens.
//     $name    = Name der Postgres-Datenbank
//     $schema  = Datenbank-Schema (Voreinstellung: public)
// BEISPIEL
//   $datenbank = new cl_database("beispieldb");
//****
  function cl_database ($name, $schema = "public")
  {
    // Datenbankname merken
    $this->DBNAME = $name;
    // Schema merken
    $this->SCHEMA = $schema;

    // Fehlertexte eintragen
    $this->error_name (CL_DATABASE_OK,"OK");
    $this->error_name (CL_DATABASE_ERROR_CANTOPEN,
                       "Can't open Database ".$this->DBNAME);
    $this->error_name (CL_DATABASE_ERROR_SQL,
                       "Error while executing SQL-query");
    $this->error_name (CL_DATABASE_ERROR_UNKNOWN,"Unknown Error");

    // Postgres-Datenbank oeffnen
    $this->TESTMODE = false; // Testmode ausschalten
    $this->datenbank_oeffnen ();
  }

//****f* database.inc/liste4selection (Tabelle, where, key, Anzeige)
// FUNCTION
//   liste4selection Array mit Daten fuer eine Selektion
//     Tabelle        aus welcher Tabelle wird selectiert
//     where          SQL-Befehl
//     key            Feld mit dem Selektions-Key
//     Anzeige        Welche Felder sollen angezeigt werden incl. Format
// ERGEBNIS
//   Es wird ein Array mit folgenden Daten zurueck gegeben:
//     KEY        = key 
//     VALUE      = Anzeige
//****
  function liste4selection ($tabelle, $where, $schluessel, $anzeige)
  {
    $WHERE = ($where == "" ) ? "" : "WHERE $where";
    $this->sql_befehl (
      "SELECT $schluessel AS schluessel".
      "     , $anzeige    AS anzeige".
      "  FROM $tabelle".
      " $WHERE".
      " ORDER BY anzeige");  
    $i = 0; while ($i < $this->sql_lines())
    {
	    $data = $this->sql_line ($i); $i++;
	    $LISTE [$data->schluessel] = $data->anzeige;
    }
    return ($LISTE);
  } 

} // Ende der Klasse
?>