<?php

//****h* DATAUS-Klasse/dataus-datei.inc
// KLASSE
//   cl_dataus
//   Klasse fuer den Datenaustausch mit einem deutschen Kreditinstitut
//   Es wird eine Textdatei erstellt, die zur Bank hochgeladen werden
//   kann.
// HISTORIE
//   20.12.2009 Deutsche Umlaute integriert
//   05.07.2009 Klasse erstellt
// BUGS
//   keine
//****

class cl_dataus
{
//****f* dataus-datei.inc/checkDIN66003 (Art, Wert)
// SICHTBAR
//   Die Funktion ist nur innerhalb der Klasse aufrufbar
// BESCHREIBUNG
//   checkDIN66003 ($Art, $Wert)
//     $Art        Art des Wertes
//                 1  Text
//                 2  Zahl
//     $Wert       Zahl oder Text, der angepasst werden soll
//   Die Anpassung erfolgt nach den Richtlinien der DIN 66003
//****
private function checkDIN66003 ($art, $wert)
{
  $wert = str_replace ("Ä","AE",$wert);
  $wert = str_replace ("ä","AE",$wert);
  $wert = str_replace ("Ö","OE",$wert);
  $wert = str_replace ("ö","OE",$wert);
  $wert = str_replace ("Ü","UE",$wert);
  $wert = str_replace ("ü","UE",$wert);
  $wert = str_replace ("ß","SS",$wert);
  switch ($art)
  {
    case 1 : // Text
      $ZEICHEN = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ .,&-/+*$%";
      break;
    case 2 : // Zahlen
      $ZEICHEN = "0123456789";
      break;
  }
  $RET = "";
  $w = 0; while ($w < strlen($wert))
  {
    $ws = substr($wert,$w,1);
    $GEFUNDEN = false;
    switch (ord($ws))
    {
      case 196 : $ws = "AE"; $GEFUNDEN = true; break;
      case 228 : $ws = "AE"; $GEFUNDEN = true; break;
      case 214 : $ws = "OE"; $GEFUNDEN = true; break;
      case 246 : $ws = "OE"; $GEFUNDEN = true; break;
      case 220 : $ws = "UE"; $GEFUNDEN = true; break;
      case 252 : $ws = "UE"; $GEFUNDEN = true; break;
      case 223 : $ws = "SS"; $GEFUNDEN = true; break;
      default: 
        $z = 0; while ($z < strlen ($ZEICHEN))
        {
          $zs = substr($ZEICHEN,$z,1);
          $F = strpos ($ws,$zs);
          $GEFUNDEN = ($F === false) ? $GEFUNDEN : true;
          if ($GEFUNDEN) $z = strlen($ZEICHEN);
          $z++;
        }
        break;
    }         
    $RET .= ($GEFUNDEN === false) ? " " : $ws;
    $w++;
  }
  return ($RET);
}
//****f* dataus-datei.inc/feldwert (Wert, Art, Laenge, Nachkommastellen)
// SICHTBAR
//   Die Funktion ist nur innerhalb der Klasse aufrufbar
// BESCHREIBUNG
//   feldwert ($Wert, $Art, $Laenge, [$Nachkomma])
//     $Wert       Zahl oder Text, der angepasst werden soll
//     $Art        Art des Wertes
//                 1  Text - wird rechts bis maximal $Laenge mit Leerzeichen
//                    aufgefuellt
//                 2  Zahl - wird links bis maximal $Laenge mit Nullen auf-
//                    gefuellt
//     $Laenge     Laenge des Ergebnis-Strings
//                 Wenn der Wert laenger als $Laenge ist, wird er auf $Laenge
//                 gekuerzt - ansonsten wird der Wert je nach $Art aufgefuellt
//     $Nachkomma  Anzahl der Nachkommastellen bei Zahlen - Voreinstellung ist
//                 keine Nachkommastellen
//   Die Anpassung erfolgt nach den Richtlinien der DIN 66003
//****
private function feldwert ($wert, $art, $laenge, $nachkomma = 0)
{
  switch ($art)
  {
    case 1 : // Alpha
      $wert = $this->checkDIN66003 (1, strtoupper($wert));
      $RET = substr(str_pad($wert,$laenge," "),0,$laenge);
      break;
    case 2 : // Zahlen
      $wert = ($wert == "") ? 0 : $wert;
      $wert = str_replace (",",".",trim($wert));
      $wert = str_replace ("|",".",$wert);
      $wert = (is_numeric($wert)) ? $wert : 0;
      $wert = number_format ($wert,$nachkomma,"","");
      $wert = $this->checkDIN66003 (2, $wert);
      $RET = substr(str_pad($wert,$laenge,"0",STR_PAD_LEFT),0,$laenge);
      break;
  }
  return ($RET);
}
  
//****c* dataus-datei.inc/cl_dataus (Name, Bankleitzahl, Konto-Nr)
// BESCHREIBUNG
//   Konstruktor fuer die DATAUS-Klasse
//   Uebergabe-Paramter:
//      Name          Fuer wen wird die Datei erstellt
//      Bankleitzahl  Bankleitzahl der eigenen Bank
//      Konto-Nr      Eigene Konto-Nr.
//****
function __construct($absender, $bankleitzahl, $kontonr) 
{
  $this->A_SATZ  = "0128";                            // Satzlaenge
  $this->A_SATZ .= "A";                               // Satzart
  $this->A_SATZ .= "LK";                              // Bankeinzug
  $this->A_SATZ .= $this->feldwert($bankleitzahl,2,8);// Bankleitzahl
  $this->A_SATZ .= $this->feldwert(0,2,8);            // Nullen
  $this->A_SATZ .= $this->feldwert($absender,1,27);   // Absender
  $this->A_SATZ .= date("d");                         // Tag
  $this->A_SATZ .= date("m");                         // Monat
  $this->A_SATZ .= date("y");                         // Jahr
  $this->A_SATZ .= $this->feldwert(" ",1,4);          // Leerstellen
  $this->A_SATZ .= $this->feldwert($kontonr,2,10);    // Konto-Nr.
  $this->A_SATZ .= $this->feldwert(0,2,10);           // Nullen
  $this->A_SATZ .= $this->feldwert(" ",1,47);         // Leerstellen
  $this->A_SATZ .= "1";                               // 1 = Euro
  $this->EIGENE_BLZ  = $bankleitzahl;
  $this->EIGENE_KTO  = $kontonr;
  $this->EIGENE_NAME = $absender;
  $this->SUMME_KONTO = 0;
  $this->SUMME_BLZ = 0;
  $this->SUMME_BETRAG = 0;
  $this->ANZAHL = 0;
  $this->C_SATZ = "";
}
  
//****f* dataus-datei.inc/buchung (BLZ, Konto-Nr, Name, Zweck, Betrag)
// SICHTBAR
//   Die Funktion ist public
// BESCHREIBUNG
//   buchung ($bls, $kto, $name, $zweck, $betrag)
//     $blz     Bankleitzahl
//     $kto     Konto-Nr
//     $name    Name
//     $zweck   Verwendungszweck
//     $betrag  Betrag, der eingezogen werden soll
//
//   Erstellt die einzelnen Positionen des DATAUS-Satzes
//****
public function buchung ($blz,$kto,$name,$zweck,$betrag)
{
  $this->C_SATZ .= "0187C" . $this->feldwert(0,2,8). $this->feldwert($blz,2,8).
                   $this->feldwert($kto,2,10) . $this->feldwert (0,2,13).
                   "05000 " . $this->feldwert (0,2,11) . 
                   $this->feldwert ($this->EIGENE_BLZ,2,8).
                   $this->feldwert ($this->EIGENE_KTO,2,10).
                   $this->feldwert ($betrag,2,11,2) . $this->feldwert(" ",1,3) . 
                   $this->feldwert ($name,1,27) . $this->feldwert (" ",1,8) . 
                   $this->feldwert ($this->EIGENE_NAME,1,27) .
                   $this->feldwert ($zweck,1,27) .
                   "1" . $this->feldwert (" ",1,2) . "00" .
                   $this->feldwert (" ",1,69);
   $this->ANZAHL++;
   $this->SUMME_KONTO  += $kto;
   $this->SUMME_BLZ    += $blz;
   $this->SUMME_BETRAG += $this->feldwert($betrag,2,11,2);
}  
  
//****f* dataus-datei.inc/ausgeben ()
// SICHTBAR
//   Die Funktion ist public
// BESCHREIBUNG
//   ausgeben ()
//
//   Erstellt die DATAUS-Datei und bietet sie zum Download an.
//****
public function ausgeben ()
{
  $FNAME = "/tmp/DATAUS.TXT";
  $F_ile = fopen ($FNAME,"w");
  fwrite ($F_ile,$this->A_SATZ);
  fwrite ($F_ile,$this->C_SATZ);
  fwrite ($F_ile,$this->feldwert("0128E",1,10).$this->feldwert($this->ANZAHL,2,7).
                 $this->feldwert(0,2,13).$this->feldwert($this->SUMME_KONTO,2,17).
                 $this->feldwert($this->SUMME_BLZ,2,17).$this->feldwert($this->SUMME_BETRAG,2,13).
                 $this->feldwert(" ",1,50));  // 50, da Download 1 Leerzeichen an die Datei anhaengt
  fclose ($F_ile);
  header ("Content-Type: text/plain");
  header ("Content-Disposition: attachment; filename=\"DATAUS.TXT\"");
  readfile ($FNAME);
}                

} // Ende der Klasse

?>