<?php
//****h* /formular.inc
// KLASSE
//   cl_formular
//     Diese Klasse ist fuer die Verwaltung und Auswertung der Formulare zu-
//     staendig. Alle Eingaben sollen durch diese Klasse abgebildet werden.
// HISTORIE
//   15.12.2007 Klasse erstellt
//   28.12.2007 Klasse um Checkbox ergaenzt
//   07.02.2009 Klasse um die Funktionen getupload und upload ergaenzt 
//   12.03.2008 Klasse um Radiobutton ergaenzt
//   17.03.2008 Bug "fehlerhafte Target-Angabe" beseitigt
//   23.05.2009 Grafik-Button erhaelt variable Groesse (set_grafikwidth)
//   28.03.2010 Klasse um "setwert" ergaenzt
//   11.05.2010 Returnwert rechnet deutsche Umlaute um
//   13.08.2010 Sonderfall - Variable = Array in returnwert beruecksichtigt
//   20.08.2011 BUG 3392871 - SUB-Formular eingefuegt (Funktionen: open_sub
//              und close_sub)
//   11.10.2014 Ticket #19 XSS-Lücke geschlossen
// BUGS
//   keine bekannt
//****

//****c* formular.inc/cl_formular
class cl_formular
{
// VARIABLE
//   Name                privat  Inhalt
//   --------------------------------------------------------------------------
//   $Name               ja      Name des Formulars
  var $Name;
//   $formular_ziel      ja      Ziel-Datei fuer das Formular
  var $formular_ziel;
//   $formular_target    ja      Ziel-Frame fuer das Formular
  var $formular_target;
//   $FORMULAR           ja      Das Formular selbst
  var $FORMULAR;
//   $INTERNE_VARIABLEN  ja      Welche Werte wurden an das Formular uebergeben
  var $INTERNE_VARIABLEN;
//   $tausend            nein    Trennzeichen fuer Tausender (deutsch z.B. ".")
  var $tausend;
//   $trenner            nein    Trennzeichen fuer Nachkommastellen (z.B. ",")
  var $trenner;
//   $set_grafikwidth    nein    Breite des Grafik-Buttons (Voreinstellung: 25)
  var $set_grafikwidth;
//   $SUB_FORM           ja      Nummer des Unterformulars, falls vorhanden
  var $SUB_FORM;
//****

//****c* cl_formular/cl_formular (Ziel, Frame)
// FUNCTION
//   cl_formular ([$ziel],[$target])
//   Konstruktor der Klasse. Zur Initialisierung koennen verschiedene optionale
//   Parameter uebergeben werden.
//     $ziel     CGI-Script fuer die Auswertung des Formulars
//     $target   Frame fuer den Aufruf des CGI-Scripts fuer die Auswertung
// BEISPIEL
//   * Ohne Parameter wird die aktuelle Datei und der aktuelle Frame als CGI-
//     Script fuer die Auswertung verwandt.
//       $FORMULAR = new cl_formular ();
//  
//   * Wenn nur das Ziel angegeben wird, und kein Frame wird der aktuelle Frame
//     beibehalten und das uebergebene Ziel als CGI-Script verwandt.
//       $FORMULAR = new cl_formular ("auswerten.php");
//
//   * Wenn Ziel und Frame uebergeben wird, erfolgt die Auswertung durch das 
//     als Ziel uebergeben CGI-Script im als Target uebergebenen Frame.
//       $FORMULAR = new cl_formular ("auswerten.php","_blank");
//
//   * Wenn die aktuelle Datei als CGI-Script verwandt werden soll, aber ein
//     anderer Frame genutzt wird, muss NULL als Ziel-Parameter angegeben
//     werden.
//       $FORMULAR = new cl_formular (NULL,"_blank"); 
//****
  function cl_formular ($ziel = NULL, $target = NULL)
  {
    $this->formular_ziel   = ($ziel == NULL) ? $_SERVER['PHP_SELF'] : $ziel;
    $this->formular_target = ($target == NULL) ? "_self" : $target;
    $this->Name = "FORM_" . time();
    $this->FORMULAR = "<FORM action=\"".$this->formular_ziel."\"".
                      " name=\"".$this->Name."\"".
                      " method=\"POST\"".
                      " enctype=\"multipart/form-data\"".
                      " target=\"".$this->formular_target."\">";
    $this->tausend = ".";
    $this->trenner = ",";
    $this->set_grafikwidth = 25;
    $this->SUB_FORM = 1;
  }

//****f* cl_formular/INT_UML_2_HTML (text)
// FUNCTION
//   INT_UML_2_HTML ($text)
//     $text    Text der umgerechnet werden soll
//
//   Umlaute werden als HTML-Code zurueck gegeben
//****
function INT_UML_2_HTML ($text)
{
  $UML2HTML_ARRAY = array 
    ("Ã¤" => "&auml;" ,"ä" => "&auml;",  chr(228) => "&auml;",
     "Ã„" => "&Auml;" ,"Ä" => "&Auml;",  chr(196) => "&Auml;",
     "Ã¶" => "&ouml;" ,"ö" => "&ouml;",  chr(246) => "&ouml;",
     "Ã–" => "&Ouml;" ,"Ö" => "&Ouml;",  chr(214) => "&Ouml;",
     "Ã¼" => "&uuml;" ,"ü" => "&uuml;",  chr(252) => "&uuml;", "�" => "&uuml;",
     "Ãœ" => "&Uuml;" ,"Ü" => "&Uuml;",  chr(220) => "&Uuml;",
     "ÃŸ" => "&szlig;","ß" => "&szlig;", chr(223) => "&szlig;"
    );
  return(strtr($text,$UML2HTML_ARRAY));		                    
}

//****f* cl_formular/INT_HTML_2_UML (text)
// FUNCTION
//   INT_HTML_2_UML ($text)
//     $text    Text der umgerechnet werden soll
//
//   HTML-Code wird als Umlaut zurueck gegeben
//****
function INT_HTML_2_UML ($text)
{
  $HTML2UML_ARRAY = array ("&auml;"  => "ä",
                           "&Auml;"  => "Ä",
                           "&ouml;"  => "ö",
                           "&Ouml;"  => "Ö",
	                        "&uuml;"  => "ü",
	                        "&Uuml;"  => "Ü",
                           "&szlig;" => "ß"
		                    );
  return(strtr($text,$HTML2UML_ARRAY));		                    
}

//****f* cl_formular/setwert (Name,inhalt)
// FUNCTION
//   setwert ($name,$inhalt)
//     $name    Name der Variablen
//     $inhalt  Wert, der fuer die Variable gesetzt werden soll
//
// ERGEBNIS
//   Der Inhalt wird gesetzt und bei allen anschliessenden Leseoperationen
//   zurueckgeliefert.
// BEISPIEL
//   $FORMULAR->setwert("wasislos","Nix is los");
//****
  function setwert ($name,$inhalt)
  {
    $_POST[$name] = $inhalt;
  }

//****f* cl_formular/returnwert (Name)
// FUNCTION
//   returnwert ($name)
//     $name    Name der Variablen
//
//   Mit dieser Funktion wird das Formular nach Uebermittlung ausgelesen.
// ERGEBNIS
//   Die Funktion gibt den Inhalt des Formularfeldes zurueck. Ist das Feld leer
//   oder wurde das Formular noch nicht abgeschickt kommt als Ergebnis ein
//   leerer String zurueck.
// BEISPIEL
//   eingabe = $FORMULAR->returnwert ("eingabe");
//****
  function returnwert ($name)
  {
    $checkup = explode ("[",$name);     // Soll ein Array ausgelesen werden ?
    if (count ($checkup) > 1)           // Ja - Array auslesen
    {
      $v_name = $checkup[0];
      $checkup = explode ("]",$checkup[1]);
      $v_element = $checkup[0];
      $v_wert = (empty($_POST[$v_name])) ? "" : $_POST[$v_name];
      $wert = (@empty($v_wert[$v_element])) ? "" : $v_wert[$v_element];
    }
    else                                // Nein - kein Array
    {
      $wert = (empty($_POST[$name])) ? "" : $_POST[$name];
    }
    if (is_array($wert) === false)  // Wurde ein komplettes Array ausgelesen ?
    {                               // Nein
      $wert = $this->INT_UML_2_HTML ($wert);
      $wert = $this->INT_HTML_2_UML ($wert);
    }
    else 
    {                               // Ja
      $ARR = $wert;
      foreach ($ARR as $key => $inhalt)
      {
      	$wert[$key] = $this->INT_UML_2_HTML ($inhalt);
      	$wert[$key] = $this->INT_HTML_2_UML ($wert[$key]);
      }
    }
    $wert = htmlentities($wert, ENT_QUOTES, 'UTF-8');
    return($wert);
  }

//****f* cl_formular/returnzahl (Name)
// FUNCTION
//   returnzahl ($name)
//     $name    Name der Variablen
//
//   Mit dieser Funktion wird das Formular nach Uebermittlung ausgelesen.
// ERGEBNIS
//   Die Funktion gibt den Inhalt des Formularfeldes zurueck. Ist das Feld leer
//   oder wurde das Formular noch nicht abgeschickt kommt als Ergebnis die Zahl
//   0 zurueck.
// BEISPIEL
//   eingabe = $FORMULAR->returnzahl ("eingabe");
//****
  function returnzahl ($name)
  {
    $zahl = $this->returnwert($name);
    $zahl = ($zahl == "") ? 0 : $zahl;
    $zahl = str_replace("|",".",
            str_replace(",",".",
            str_replace(".","",trim($zahl))));
    $zahl = (is_numeric ($zahl)) ? $zahl : 0;
    return($zahl);
  }


//****f* cl_formular/returnglobal (Name, [Vorgabe])
// FUNCTION
//   returnglobal (Name, Zahl = "")
//     Name     Name der Variablen
//     Vorgabe  Statt Leerzeichen soll Vorgabewert geliefert werden
//              Wenn die Vorgabe eine Zahl ist, wird ein numerischer
//              Wert ausgelesen.
//
//   Mit dieser Funktion wird das Formular nach der Uebermittlung ausgelesen -
//   falls der Wert nicht im Formular uebergeben wurde wird zusaetzlich ge-
//   prueft ob das Feld ueber die Browser-Funktion direkt uebergeben wurde und
//   ggf. eingelesen.
// ERGEBNIS
//   Die Funktion gibt den Inhalt des Formularfeldes bzw. alternativ einen
//   direkt uebergebenen Wert zurueck. Ist das Feld leer kommt als Ergebnis ein
//   leerer String zurueck.
// BEISPIEL
//   $eingabe = $FORMULAR->returnglobal ("eingabe");
//****
  function returnglobal ($name,$vorgabe = "")
  {
    $wert = $this->returnwert($name);
    if ($wert == "")
    {
      $wert = (empty($_REQUEST[$name])) ? $wert : $_REQUEST[$name];
    }
    $wert = ($wert == "") ? $vorgabe : $wert;
    $wert = $this->INT_UML_2_HTML ($wert);
    $wert = $this->INT_HTML_2_UML ($wert); 
    if (is_numeric ($vorgabe)) 
    {
      $wert = ($wert == "") ? 0 : $wert;
      $wert = str_replace("|",".",
              str_replace(",",".",
              str_replace(".","",trim($wert))));
      $wert = (is_numeric ($wert)) ? $wert : 0;
    }
    $wert = htmlentities($wert, ENT_QUOTES, 'UTF-8');
    return ($wert);
  }

//****f* cl_formular/hide (Name, Wert)
// FUNCTION
//   hide ($name, [$wert])
//     $name    Name der Variablen
//     $wert    Inhalt der Variablen (wenn kein Wert uebergeben wird,
//              wird der Wert aus den Superglobals direkt ausgelesen)
//
//   Variablenwerte in Formular einfuegen, die nicht angezeigt werden
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//   Die Auswertung erfolgt nach Formularuebermittlung ueber die Funktionen
//   returnwert und/oder returnzahl.
// BEISPIEL
//   $FORMULAR->hide ("geschuetzt","Ja");
//****
  function hide ($name, $wert = NULL)
  {
    $wert = ($wert == NULL) ? $this->returnwert($name) : $wert;
    $this->FORMULAR .= "<INPUT type='hidden' name='$name' value='$wert'></input>";
    $this->INTERNE_VARIABLEN[$name] = $wert;
  }

//****f* cl_formular/sende_ergebnis ()
// FUNCTION
//   sende_ergebnis ()
//
//   Diese Funktion gibt das Ergebnis der letzten Uebermittlung des Formulars
//   zurueck. Ausgelesen werden die die Werte aus den Buttons
//     * senden
//     * grafikbutton
// ERGEBNIS
//   Die Funktion gibt den uebermittelten Wert des gedrueckten Buttons zurueck.
//   Wenn kein Button gedrueckt wurde wird ein leerer String zurueck gegeben.
// BEISPIEL
//   $auswahl = $FORMULAR->sende_ergebnis ();
//****
  function sende_ergebnis ()
  {
    return($this->returnglobal("senden"));
  }

//****f* cl_formular/senden (Name)
// FUNCTION
//   senden ($name)
//     $name     Text, der angezeigt wird = gleichzeitig Ergebnis
//
//   Diese Funktion stellt einen Sende-Button bereit, der mit dem uebergebenen
//   Text beschriftet wird. Der Text ist gleichzeitig der Rueckgabewert, wenn
//   der Button angeklickt wird. 
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//   Die Auswertung erfolgt nach Formularuebermittlung ueber die Funktion
//   sende_ergebnis.
// BEISPIEL
//   $FORMULAR->senden ("OK");
//   $FORMULAR->senden ("Abbruch");
//****
  function senden ($name)
  {
    $this->FORMULAR .= "<INPUT type='submit' name='senden' value='$name'></input>";
  }

//****f* cl_formular/open_sub (ziel,target)
// FUNCTION
//   open_sub ([$ziel], [$target])
//     $ziel     CGI-Script fuer die Formularauswertung
//               Voreinstellung ist das Script des aktuellen Formulars
//     $target   Frame fuer den Aufruf des CGI-Scripts
//               Voreinstellung ist der Frame des aktuellen Formulars
//
//   Die Funktion oeffnet ein Unterformular
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//****
function open_sub ($ziel = NULL, $target = NULL)
{
  if ($this->SUB_FORM <= 1) $this->FORMULAR .= "<FORM></FORM>"; // Unterformulare erlauben
  $ziel   = ($ziel == NULL)   ? $this->formular_ziel   : $ziel;
  $target = ($target == NULL) ? $this->formular_target : $target;
  $this->FORMULAR .= "<FORM action=\"$ziel\" name=\"SUBFORM_$this->SUB_FORM\"".
                      " method=\"POST\" enctype=\"multipart/form-data\"".
                      " target=\"$target\">";
  $this->SUB_FORM++;                     
}

//****f* cl_formular/close_sub ()
// FUNCTION
//   close_sub ()
//   Die Funktion schliesst ein Formular
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//****
function close_sub ()
{
  $this->FORMULAR .= "</FORM>";
}

//****f* cl_formular/grafikbutton (Wert, Pfad zur Grafikdatei,[Unterformular])
// FUNCTION
//   grafikbutton ($value, $pic)
//     $value     Rueckgabewert, wenn Button gedrueckt wurde
//     $pic       Pfad zur Grafikdatei
//     $subform   Unterformular nutzen -> Voreinstellung true
//
//   Die Funktion stellt einen Sendebutton bereit, der statt Text eine Grafik
//   anzeigt. Nach der Formularuebermittlung wird $value uebergeben falls der
//   Button angeklickt wurde.
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//   Die Auswertung erfolgt nach Formularuebermittlung ueber die Funktionen
//   sende_ergebnis.
// BEISPIEL
//   $FORMULAR->grafikbutton ("OK","../icons/ok.png");
//****
function grafikbutton ($value, $pic, $subform = true)
{
  if ($subform) $this->open_sub();
  $this->hide ("senden",$value);
  $this->FORMULAR .= "<INPUT type=\"image\" name=\"sendeni\" value=\"$value\" ".
                     "width=\"$this->set_grafikwidth\" src=\"$pic\" alt=\"$pic\" />";
  if ($subform) $this->close_sub();
}

//****f* cl_formular/eingabe (Name, Feldlaenge, Vorgabewert)
// FUNCTION
//   eingabe ($name, [$len], [$vorgabe])
//     $name     Name des Formular-Feldes
//     $len      optionaler Parameter fuer die Feldlaenge (Voreinstellung: 80)
//     $vorgabe  optionale Vorgabe fuer den Feld-Inhalt (Voreinstellung ist 
//               Inhalt lt. letztem Sendevorgang)
//
//   Die Funktion stellt ein Eingabefeld zur Verfuegung. Die Breite des Feldes
//   wird durch $len festgelegt. Falls $vorgabe mit uebergeben wird, ist dies 
//   die Vorbelegung fuer das Eingabefeld. Falls $vorgabe nicht uebergeben wird
//   ist die Vorbelegung der Eintrag des letzten Sendevorganges oder falls noch
//   kein Sendevorgang stattgefunden hat ein leerer String.
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//   Die Auswertung erfolgt nach Formularuebermittlung ueber die Funktionen
//   returnwert und/oder returnzahl.
// BEISPIEL
//   $FORMULAR->eingabe ("eingabezeile");
//****
  function eingabe ($name, $len = NULL, $vorgabe = NULL)
  {
    $len = ($len == NULL) ? 80 : $len;
    $maxlen = $len + 20;
    $vorgabe = ($vorgabe == NULL) ? $this->returnwert($name) : $vorgabe;
    $vorgabe = str_replace("\\\"", '"', $vorgabe);
    $vorgabe = html_entity_decode($vorgabe, ENT_QUOTES,'UTF-8');
    $this->FORMULAR .= "<INPUT type='text'".
                             " name='$name'".
                             " size='$len'".
                             " maxlength='$maxlen'".
                             " value='$vorgabe'>";
    $this->INTERNE_VARIABLEN[$name] = $vorgabe;
  }

//****f* cl_formular/password(Name, [Feldlaenge])
// FUNCTION
//   password ($name, $len)
//     $name     Name des Formular-Feldes
//     $len      optionaler Parameter fuer die Feldlaenge (Voreinstellung: 80)
//
//   Die Funktion stellt ein Eingabefeld fuer Passwoerter zur Verfuegung.
//   Das Passwort wird waehrend der Eingabe nicht angezeigt 
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//   Die Auswertung erfolgt nach Formularuebermittlung ueber die Funktionen
//   returnwert und/oder returnzahl.
// BEISPIEL
//   $FORMULAR->password ("PW");
//****
  function password ($name, $len = 80)
  {
    $len = ($len < 0) ? 10 : $len;
    $maxlen = $len + 20;
    $this->FORMULAR .= "<INPUT type='password'".
                             " name='$name'".
                             " size='$len'".
                             " maxlength='$maxlen'".
                             " value=''>";
    $this->INTERNE_VARIABLEN[$name] = "";
  }

//****f* cl_formular/feld Name, Breite, Hoehe, Vorgabewert)
// FUNCTION
//   feld ($name, [$breite], [$hoehe], [$vorgabe])
//     $name        Name des Eingabefeldes
//     $breite      Breite Feldes (nichts = 80)
//     $hoehe       Hoehe des Feldes (nichts = 10)
//     $vorgabe     Inhalt der Variablen (nichts = aus Superglobals holen)
//
//   Die Funktion stellt ein Eingabefeld fuer mehrzeiligen Text zur Verfuegung.
//   Breite und Hoehe des Feldes werden durch $breite und $hoehe festgelegt.
//   Falls $vorgabe mit uebergeben wird ist dies die Vorbelegung fuer das Feld.
//   Falls $vorgabe nicht uebergeben wird, ist die Vorbelegung der Eintrag beim
//   letzten Sendevorgang oder falls noch kein Sendevorgang stattgefunden hat
//   ein leerer String.
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//   Die Auswertung erfolgt nach Formularuebermittlung ueber die Funktionen
//   returnwert und/oder returnzahl.
// BEISPIEL
//   $FORMULAR->feld ("eingabefeld");
//****
  function feld ($name, $breite = NULL, $hoehe = NULL, $vorgabe = NULL)
  {
    $breite = ($breite == NULL) ? 80 : $breite;
    $hoehe  = ($hoehe  == NULL) ? 10 : $hoehe;
    $vorgabe = ($vorgabe == NULL) ? $this->returnwert($name) : $vorgabe;
    $vorgabe = str_replace("\\\"", '"', $vorgabe);
    $vorgabe = html_entity_decode($vorgabe, ENT_QUOTES,'UTF-8');
    $this->FORMULAR .= "<TEXTAREA name='$name' rows='$hoehe' cols='$breite'>".
                       $vorgabe .
                       "</TEXTAREA>";
    $this->INTERNE_VARIABLEN[$name] = $vorgabe;
  }

//****f* cl_formular/selection (Name, Array mit Selektion, selektiertes Element, Zeilenzahl)
// FUNCTION
//   selection ($name, $sel, [$selected], [$size])
//     $name      Name der Variablen
//     $sel       Array mit Selectionsangaben
//     $selected  Optional: Welches Element ist selektiert ?
//                (Voreinstellung = 1. Element bzw. lt. Superglobals)
//     $size      Optional: Anzahl der angezeigten Selection 
//                (Voreinstellung = 1)
//
//   Diese Funktion stellt ein Selektionsfeld zur Verfuegung. Die Daten fuer
//   die einzelnene Selektionszeilen werden als Array ($sel) uebergeben. Der
//   Schluessel des Array's wird hierbei als Rueckgabewert und der Array-Inhalt
//   fuer die Anzeige verwandt.
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//   Die Auswertung erfolgt nach Formularuebermittlung ueber die Funktionen
//   returnwert und/oder returnzahl.
// BEISPIEL
//   $SEL = array ("OK" => "Alles OK", "KAPUT", "zerstoert");
//   $FORMULAR->selection ("was",$SEL); 
//****
  function selection ($name, $sel, $selected = NULL, $size = NULL)
  {
    $size = ($size == NULL) ? 1 : $size;
    $selected = ($selected == NULL) ? $this->returnwert($name) : $selected;
    $this->INTERNE_VARIABLEN[$name] = $selected;
    $this->FORMULAR .= "<SELECT name='$name' size='$size'>";
    $i = 0; foreach ($sel as $key => $bezeichnung)
    {
      $SEL = ($selected == "")
           ? (($i == 0) ? "selected" : "")
	   : (($key == $selected) ? "selected" : "");
      $i++;
      $this->FORMULAR .= "<OPTION value='$key' $SEL>$bezeichnung</OPTION>";
    }
    $this->FORMULAR .= "</SELECT>";
  }
  
//****f* cl_formular/checkbox (Name, Wert, Anzeigetext, ausgewaehlt)
// FUNCTION
//   checkbox ($name, $wert, $anzeige, [$checked])
//     $name       Name der Checkbox
//     $wert       Rueckgabewert, wenn ausgewaehlt
//     $anzeige    Text fuer die Beschriftung
//     $checked    optionaler Wert. Wenn etwas uebergeben wird, ist die Box
//                 ausgewaehlt - ansonsten wird der Wert aus der letzen Ueber-
//                 mittlung des Formulars genommen. Voreinstellung = nicht aus-
//                 gewaehlt.
//
//   Die Funktion stellt eine Checkbox mit Beschriftung zur Verfuegung.
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//   Die Auswertung erfolgt nach Formularuebermittlung ueber die Funktionen
//   returnwert und/oder returnzahl.
// BEISPIEL
//   $FORMULAR->checkbox ("box","OK","bitte anklicken");
//****
  function checkbox ($name,$wert,$anzeige,$checked = NULL)
  {
    $checked = ($checked == NULL) ? $this->returnwert($name) : $checked;
    $checked = ($checked == "") ? "" : "checked=\"checked\"";
    $this->INTERNE_VARIABLEN[$name] = ($checked == "") ? "" : $wert;
    $this->FORMULAR .= "<INPUT type=\"checkbox\"".
                       " name=\"$name\"".
                       " value=\"$wert\"".
                       " ".$checked.
                       ">$anzeige</INPUT>";
  }

//****f* cl_formular/radio_button (Name, Wert, Anzeigetext, ausgewaehlt)
// FUNCTION
//   radio_button ($name, $wert, $anzeige, [$checked])
//     $name     Name des Feldes mit Radio-Buttons
//     $wert     Rueckgabewert
//     $anzeige  das was angezeigt wird
//     $checked  ausgewaehlt ? Voreinstellung = Nein bzw. Superglobals
//               Jede Angabe bedeutet ja
//
//   Die Funktion stellt Radio-Buttons zur Verfuegung. Durch $name wird festge-
//   legt, welche Buttons zusammen gehoeren.
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//   Die Auswertung erfolgt nach Formularuebermittlung ueber die Funktionen
//   returnwert und/oder returnzahl.
// BEISPIEL
//   $FORMULAR->inhalt ("Zugriffsart waehlen:");
//   $FORMULAR->radio_button ("dbart","prod","produktiv","X");
//   $FORMULAR->radio_button ("dbart","test","Test");
//****
  function radio_button ($name,$wert,$anzeige,$checked = NULL)
  {
    if ($checked == NULL)
    {
      $checked = $this->returnwert($name);
    }
    else
    {
      $checked = ($this->returnwert($name) == "") ? $wert : $this->returnwert($name);
    }
    $checked = ($checked == $wert) ? "checked=\"checked\"" : "";
    $this->FORMULAR .= "<INPUT type=\"radio\" name=\"$name\" value=\"$wert\" ";
    $this->FORMULAR .= $checked;
    $this->FORMULAR .= ">$anzeige</INPUT>";
    $this->INTERNE_VARIABLEN[$name] = ($checked == "") ? "" : $wert;
  }

//****f* cl_formular/inhalt (Text)
// FUNCTION
//   inhalt ($text)
//     $text  Text, der im Formular ausgegeben werden soll
//
//   Diese Funktion fuegt Text und ggf. HTML-Tags in das Formular ein. Dadurch
//   wird der Vordruck insgesamt uebersichtlicher.
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
// BEISPIEL
//   $FORMULAR->inhalt ("<HR>Bemerkungsfeld:<BR>");
//   $FORMULAR->feld   ("bemerkungen");
//   $FORMULAR->inhalt ("<BR><HR>");
//****
  function inhalt ($text)
  {
    $this->FORMULAR .= $this->INT_UML_2_HTML ($text);
  }

//****f* cl_formular/numeingabe2anzeige (Zahl, Nachkommastellen)
// FUNCTION
//   numeingabe2anzeige ($zahl, $nachkomma)
//     $zahl      Zahl, die fuer die Anzeige optimiert werden soll
//     $nachkomma darzustellende Nachkommastellen
//
//   Diese Funktion wandelt die uebergebene Zahl fuer die Darstellung am Bild-
//   schirm um. Die Zahl kann bereits formatiert oder unformatiert uebergeben
//   werden.
// ERGEBNIS
//   Die Funktion liefert als Rueckgabe die formatierte Zahl
// BEISPIEL
//   echo $FORMULAR->numeingabe2anzeige ("10.9",2); // gibt 10,90 aus
//   echo $FORMULAR->numeingabe2anzeige ("10,9",2); // gibt 10,90 aus
//****
  function numeingabe2anzeige ($zahl, $nachkomma)
  {
    $zahl = trim($zahl);
    $zahl = str_replace ($this->trenner,".",$zahl);  // Nachkommatrenner aendern
    $zahl = str_replace ("|",".",$zahl);             // Nachkommatrenner am Nummernblock
    $zahl = number_format($zahl,$nachkomma,$this->trenner,$this->tausend); // umrechnen
    return $zahl;
  }

//****f* cl_formular/getupload (Name der Variablen)
// FUNCTION
//   getupload ($name)
//     $name  Name der Variablen
//
//   Die Funktion stellt eine Auswahlbox fuer die Dateiauswahl auf dem Client
//   zur Verfuegung   
// ERGEBNIS
//   Die Funktion hat keinen Rueckgabewert.
//   Die Auswertung erfolgt nach Formularuebermittlung ueber die Funktionen
//   upload.
// BEISPIEL
//   $FORMULAR->getupload ("DATEI");
//****
  function getupload ($name)           // Datei auf Client auswaehlen
  {
    $this->FORMULAR .= "<INPUT type=\"file\" name=\"$name\">";
    $this->INTERNE_VARIABLEN[$name] = "";
  }

//****f* cl_formular/upload (Name der Variablen, Server-Pfad)
// FUNCTION
//   upload ($name, $uploadname)
//     $name        Name der Variablen
//     $uploadname  Pfad incl. Name unter der die Datei auf den Server hoch-
//                  geladen wird.                          
// ERGEBNIS
//   Die Funktion laedt die durch getupload ausgewaehlte Datei auf den Server
//   hoch.
// BEISPIEL
//   $FORMULAR->upload ("DATEI","/tmp/serverdatei");
//****
  function upload ($name,$uploadname)  // Upload auf Server
  {
    copy ($_FILES["$name"]["tmp_name"],"$uploadname");
  }

//****f* cl_formular/schliessen ()
// FUNCTION
//   schliessen ()
//
//   Diese Funktion beendet das Formular und liefert es als Rueckgabe.
// ERGEBNIS
//   Die Funktion gibt das komplette Formular zurueck, das weiterverarbeitet
//   oder ausgegeben werden kann.
// BEISPIEL
//   $FORMULAR = new cl_formular ();
//   $FORMULAR->inhalt ("<HR>Was tun?<BR>");
//   $FORMULAR->senden ("Nichts");
//   $FORMULAR->inhalt (" ");
//   $FORMULAR->senden ("Etwas");
//   echo $FORMULAR->schliessen();
//****
  function schliessen ()
  {
    $this->FORMULAR .= "</FORM>";
    return ($this->FORMULAR);
  }


//****f* cl_formular/sub_textbutton (Anzeige,Daten-Array,Ziel,Frame)
// FUNCTION
//   sub_textbutton ($Anzeige, $Uebermittlung, [$Ziel], [$Target])
//     $Anzeige        Text, der angezeigt wird
//     $Uebermittlung  Array mit Variablen, die durch dieses Unter-
//                     Formular uebermittelt werden sollen
//     $Ziel           Optionales Ziel des Unterformulars
//     $Target         Optionaler Frame fuer das Ziel
//
//   Diese Funktion erstellt einen Textbutton, der in ein Unterformular
//   eingebettet wird
// BEISPIEL
//   $FORMULAR = new cl_formular ();
//   $FORMULAR->inhalt ("<HR>Was tun?<BR>");
//   $FORM_DATA = array ("AUSWAHL" => "OK", "NR" => 2);
//   $FORMULAR->sub_textbutton ("OK ich mach was",$FORM_DATA);
//   $FORMULAR->inhalt (" ");
//   $FORMULAR->senden ("Etwas");
//   echo $FORMULAR->schliessen();
//****
function sub_textbutton ($Anzeige, $Uebermittlung, $Ziel = "", $Target = "")
{
  $this->open_sub($Ziel,$Target);
  foreach ($Uebermittlung as $name => $wert){$this->hide ($name,$wert);}
  $this->senden ($Anzeige);
  $this->close_sub();
}

//****f* cl_formular/sub_grafikbutton (Button,Daten-Array,Ziel,Frame)
// FUNCTION
//   sub_grafikbutton ($Button, $Uebermittlung, [$Ziel], [$Target])
//     $Button         Pfad zum Grafikbutton
//     $Uebermittlung  Array mit Variablen, die durch dieses Unter-
//                     Formular uebermittelt werden sollen
//     $Ziel           Optionales Ziel des Unterformulars
//     $Target         Optionaler Frame fuer das Ziel
//
//   Diese Funktion erstellt einen Textbutton, der in ein Unterformular
//   eingebettet wird
// BEISPIEL
//   $FORMULAR = new cl_formular ();
//   $FORMULAR->inhalt ("<HR>Was tun?<BR>");
//   $FORM_DATA = array ("AUSWAHL" => "OK", "NR" => 2);
//   $FORMULAR->sub_grafikbutton ("../icons/ok.png",$FORM_DATA);
//   $FORMULAR->inhalt (" ");
//   $FORMULAR->senden ("Etwas");
//   echo $FORMULAR->schliessen();
//****
function sub_grafikbutton ($Button, $Uebermittlung, $Ziel = "", $Target = "")
{
  $this->open_sub ($Ziel,$Target);
  if (is_array($Uebermittlung))
  { 
    foreach ($Uebermittlung as $name => $wert){$this->hide ($name,$wert);}
  }
  $this->FORMULAR .= "<INPUT type=\"image\" name=\"SUBFORM_$this->SUB_FORM\" ".
                     "width=\"$this->set_grafikwidth\" src=\"$Button\" alt=\"$Button\" />";
  $this->close_sub();
}

//****f* cl_formular/sub_mixbutton (Button,Anzeige,Daten-Array,Ziel,Frame)
// FUNCTION
//   sub_mixbutton ($Button,$Anzeige,$Uebermittlung,[$Ziel],[$Target])
//     $Button         Pfad zum Grafikbutton
//     $Anzeige        Text, zum Button ausgebeben wird
//     $Uebermittlung  Array mit Variablen, die durch dieses Unter-
//                     Formular uebermittelt werden sollen
//     $Ziel           Optionales Ziel des Unterformulars
//     $Target         Optionaler Frame fuer das Ziel
//
//   Diese Funktion erstellt einen Grafikbutton mit Beschriftung, der in ein 
//   Unterformular eingebettet wird
//
//   Achtung: Die im Daten-Array uebergebenen Variablen koennen nur ueber
//            returnglobal ausgelesen werden und werden nur uebermittelt, wenn
//            dieser Button angeklickt wird
// BEISPIEL
//   $FORMULAR = new cl_formular ();
//   $FORMULAR->inhalt ("<HR>Was tun?<BR>");
//   $FORM_DATA = array ("AUSWAHL" => "OK", "NR" => 2);
//   $FORMULAR->sub_mixbutton ("../icons/ok.png","TESTING",$FORM_DATA);
//   $FORMULAR->inhalt (" ");
//   $FORMULAR->senden ("Etwas");
//   echo $FORMULAR->schliessen();
//****
function sub_mixbutton ($Button,$Anzeige,$Uebermittlung,$Ziel = "",$Target = "")
{
  $Ziel   = ($Ziel   == "") ? $this->formular_ziel   : $Ziel;
  $Target = ($Target == "") ? $this->formular_target : $Target;
  if (is_array($Uebermittlung))
  {
  	 $Ziel .= "?X=X";
    foreach ($Uebermittlung as $name => $wert){$Ziel .= "&".$name."=$wert";}
  }
  $this->FORMULAR .= "<A href=\"$Ziel\" target=\"$Target\">";  
  $this->FORMULAR .= "<TABLE border=\"0\" width=\"$this->grafikwidth\">";
  $this->FORMULAR .= "<TR><TD align=\"center\">";
  $this->FORMULAR .= "<IMG src=\"$Button\"".
                     "     alt=\"$Anzeige\"".
                     "   width=\"$this->set_grafikwidth\"".
                     "  border=\"0\">";
  $this->FORMULAR .= "</TD></TR>";
  if ( ! empty($Anzeige))
    $this->FORMULAR .= "<TR><TD align=\"center\" style=\"font-size:3mm\">$Anzeige</TD></TR>";
  $this->FORMULAR .= "</TABLE></A>";
}

//****f* cl_formular/fokus (name)
// FUNCTION
//   fokus ($name)
//     $name   Name des Eingabefeldes
//
// ERGEBNIS
//   Die Funktion gibt den Eingabefokus an das gewuenschte Eingabefeld
//****
function fokus ($name)
{
  $this->FORMULAR .= "<SCRIPT language=\"JavaScript\"> document.";
  $this->FORMULAR .= $this->Name;
  $this->FORMULAR .= "." .$name .".focus(); </SCRIPT>";
}

//****f* cl_formular/test ()
// FUNCTION
//   test ()
//
//   Diese Funktion ist nur fuer den Formular-Test bestimmt und sollte daher im
//   endgueltigen Dokument auskommentiert oder entfernt werden.
// ERGEBNIS
//   Die Funktion gibt alle Formularfelder mit Vorgabewert sowie alle durch den
//   letzten Sendevorgang uebermittelten Felder zurueck.
// BEISPIEL
//   echo $FORMULAR->test();
//****
  function test ()
  {
    $ret  = "<HR><H1>TEST-INFO</H1>class cl_formular ($this->formular_ziel)<HR>";
    $ret .= "<TABLE border=\"1\"><TR><TH>Name</TH><TH>Inhalt</TH></TR>\n";
    $ret .= "<TR><TD colspan=\"2\"><B>\$_POST</B></TD></TR>";
    if (! empty($_POST)) {
    foreach ($_POST as $key => $inhalt)
    {
      $ret .= "<TR><TD>$key</TD><TD>".htmlentities($inhalt, ENT_QUOTES, 'UTF-8')."</TD></TR>\n";
    }}
    $ret .= "<TR><TD colspan=\"2\"><B>Interne Werte</B></TD></TR>";
    if (! empty($this->INTERNE_VARIABLEN)) {
    foreach ($this->INTERNE_VARIABLEN as $key => $inhalt)
    {
      $ret .= "<TR><TD>$key</TD><TD>".htmlentities($inhalt, ENT_QUOTES, 'UTF-8')."</TD></TR>\n";
    }}
    $ret .= "</TABLE>\n";
    return ($ret);
  }
}

?>