<?php
//****h* SEPA-Klasse/sepa-xml.inc
// KLASSE
//   cl_sepa
//   Klasse fuer den Datenaustausch mit Banken im SEPA-Raum
//   Es wird eine XML-Datei erstellt, die zur Bank hochgeladen werden
//   kann.
// HISTORIE
//   29.12.2013 Start
// BUGS
//   keine
//****

class cl_sepa
{
//****c* sepa-xml.inc/cl_sepa (art,sequenz)
// BESCHREIBUNG
//   Konstruktor fuer die SEPA-Klasse
//   Uebergabe-Paramter:
//     art        Art des SEPA-Auftrages
//                * BASIS      = Basis-Lastschrift (Voreinstellung)
//     sequenz    Sequenz für die Lastschrift -> wird nicht automatisch geprüft
//                * FRST       = Erst-Lastschrift
//                * RCUR       = Folge-Lastschrift (Voreinstellung)
//                * 00FF       = Einmal-Lastschrift
//                * FNAL       = Letzmalige Lastschrift
//****
function __construct($art = "BASIS",$sequenz = "RCUR")
{
  $this->SEPA_ID = date("U");
  $this->BASIS_INFO["SEQUENZ"] = $sequenz;
	switch (strtoupper($art))
	{
		case 'BASIS' : // Basis-Lastschrift
      $this->BASIS_INFO["ART"] = "SLEV";
		  $this->PAIN = "008.003.02";
		  break;
	}
  $this->SEPA_ANZAHL = 0;
  $this->SEPA_BETRAG = 0.00;
}

//****v* sepa-xml.inc
// VARIABLE
//   Name                 Privat Beschreibung
//   SEPA_ID              ja     ID des Datensatzes
private $SEPA_ID;
//   PAIN                 ja     Art des Dokuments im Pain-Format
private $PAIN;
//   SEPA_ANZAHL          ja     Anzahl der Datensätze
private $SEPA_ANZAHL;
//   SEPA_BETRAG          ja     Gesamt-Betrag
private $SEPA_BETRAG;
//   SEPA_EINZEL          ja     XML-Teil mit einzelnen Beträgen
private $SEPA_EINZEL;
//   SEPA_ZAHLUNG         ja     Informationen zu den einzelnen Zahlungen
private $SEPA_ZAHLUNG;
//   BASIS_INFO           ja     Array mit Basisinformationen
private $BASIS_INFO;
//****

//****f* sepa-xml.inc/convert_mit_leerzeichen (Zeile)
// SICHTBAR
//   Die Funktion ist nur innerhalb der Klasse aufrufbar
// BESCHREIBUNG
//   Konvertiert Zeile in Zeichenkette mit eingeschränktem Zeichensatz
//   mit Leerzeichen
//   Der Zeichensatz besteht aus folgenden Zeichen:
//     Numerische Zeichen 0 bis 9
//     Buchstaben         A bis Z und a bis z
//     Sonderzeichen      :?,-(+.)/
//   Übergabe-Parameter:
//     Zeile
//   Rückgabe:
//     konvertierte Zeichenkette
//****
private function convert_mit_leerzeichen ($line)
{
  // Deutsche Umlaute umwandeln
  $suchstr   = array ("Ä", "ä", "Ö", "ö", "Ü", "ü", "ß");
  $ersatzstr = array ("Ae","ae","Oe","oe","Ue","ue","ss");
  $func_intern = str_replace($suchstr,$ersatzstr,$line);
  // Begrenzter Zeichensatz - nicht zulässige Zeichen entfernen
  $suchstr = array(
    "0","1","2","3","4","5","6","7","8","9",
    "A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z",
    "a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z",
    ":","?",",","-","(","+",".",")","/"," ");
  $func_return = "";
  $i = 0; while ($i < strlen($func_intern))
  {
    $func_return .= (in_array(substr($func_intern,$i,1),$suchstr))
                  ? substr($func_intern,$i,1)
                  : "";
    $i++;
  }
  return ($func_return);
}

//****f* sepa-xml.inc/convert_min_ohne_leerzeichen (Zeile)
// SICHTBAR
//   Die Funktion ist nur innerhalb der Klasse aufrufbar
// BESCHREIBUNG
//   Konvertiert Zeile in Zeichenkette mit eingeschränktem Zeichensatz
//   ohne Leerzeichen
//   Der Zeichensatz besteht aus folgenden Zeichen:
//     Numerische Zeichen 0 bis 9
//     Buchstaben         A bis Z und a bis z
//     Sonderzeichen      :?,-(+.)/
//   Übergabe-Parameter:
//     Zeile
//   Rückgabe:
//     konvertierte Zeichenkette
//****
private function convert_min_ohne_leerzeichen ($line)
{
  $func_return = str_replace (" ","",$line);
  $func_return = $this->convert_mit_leerzeichen ($func_return);
  return ($func_return);
}

//****f* sepa-xml.inc/absender (Name,IBAN,BIC,Gläubiger-ID)
// SICHTBAR
//   öffentlich sichtbar
// BESCHREIBUNG
//   Absenderangaben
//   Übergabe-Parameter:
//     Name
//     IBAN
//     BIC
//     IDENTNR    Gläubiger-Identifikation (in Deutschland von der Bundesbank ausgestellt)
//****
public function absender ($name,$iban,$bic,$identnr)
{
  $this->BASIS_INFO ["NAME"]    = $this->convert_mit_leerzeichen($name);
  $this->BASIS_INFO ["IBAN"]    = strtoupper($iban);
  $this->BASIS_INFO ["BIC"]     = strtoupper($bic);
  $this->BASIS_INFO ["IDENTNR"] = $identnr;
}

//****f* sepa-xml.inc/lastschrift (Mandant,Betrag,BIC,IBAN,Name,Verwendung)
// SICHTBAR
//   öffentlich sichtbar
// BESCHREIBUNG
//   Einzelner Datensatz für die Lastschrift
//   Übergabeparameter
//     * Mandant = Array mit den SEPA-Mandanten-Daten
//               ID        = Mandanten-ID
//               DATE      = Unterschriftsdatum
//     * Betrag = Euro-Betrag für die Abbuchung
//     * BIC
//     * IBAN
//     * Name = Name des Zahlungspflichtigen
//     * Verwendung = Verwendungszweck im Kontoauszug des Mitglieds
//****
public function lastschrift ($mandant,$betrag,$bic,$iban,$name,$verwendung)
{
  $this->SEPA_ZAHLUNG[$this->SEPA_ANZAHL]["MANDANT"] = sprintf("%d",$mandant["ID"]);
  $this->SEPA_ZAHLUNG[$this->SEPA_ANZAHL]["UNTERSCHRIFT"] = date("Y-m-d",strtotime($mandant["DATE"]));
  $this->SEPA_ZAHLUNG[$this->SEPA_ANZAHL]["BETRAG"]  = sprintf ("%01.2f",$betrag);
  $this->SEPA_ZAHLUNG[$this->SEPA_ANZAHL]["NAME"] = $this->convert_mit_leerzeichen($name);
  $this->SEPA_ZAHLUNG[$this->SEPA_ANZAHL]["IBAN"] = $this->convert_min_ohne_leerzeichen($iban);
  $this->SEPA_ZAHLUNG[$this->SEPA_ANZAHL]["VERWENDUNG"] = substr($this->convert_mit_leerzeichen($verwendung),0,140);
  $this->SEPA_ZAHLUNG[$this->SEPA_ANZAHL]["BIC"] = $this->convert_min_ohne_leerzeichen($bic);
  $this->SEPA_ANZAHL ++;
  $this->SEPA_BETRAG += $betrag;
}

//****f* sepa-xml.inc/ausgeben ()
// SICHTBAR
//   öffentlich sichtbar
// BESCHREIBUNG
//   XML-Datei zusamensetzen und als Zeichenkette ausgeben
//   Uebergabe-Paramter:
//     keine
//****
public function ausgeben ()
{
  return($this->makexml());
}

//****f* sepa-xml.inc/makexml ()
// SICHTBAR
//   Die Funktion ist nur innerhalb der Klasse aufrufbar
//  BESCHREIBUNG
//    Die Funktion erstellt die XML-Daten
//****
private function makexml ()
{
  // XML-Header
  $XML  = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\n";
  // Beschreibung des Dokuments
  $XML .= "<Document".
          " xmlns=\"urn:iso:std:iso:20022:tech:xsd:pain.".$this->PAIN."\"".
          " xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"".
          " xsi:schemaLocation=\"urn:iso:std:iso:20022:tech:xsd:pain.".$this->PAIN.
          " pain.".$this->PAIN.".xsd\">\n";
  // Hier beginnt das SEPA-Dokument
  $XML .= "    <CstmrDrctDbtInitn>\n";
  // Kopfbereich mit allgemeinen Angaben
  $XML .= "        <GrpHdr>\n";
  $XML .= "            <MsgId>".substr($this->convert_min_ohne_leerzeichen("MSG$this->SEPA_ID"),0,35)."</MsgId>\n";
  $XML .= "            <CreDtTm>".date ("Y-m-d\TH:i:s",strtotime('-1 hour'))."</CreDtTm>\n";
  $XML .= "            <NbOfTxs>".sprintf ("%d",$this->SEPA_ANZAHL)."</NbOfTxs>\n";
  $XML .= "            <CtrlSum>".sprintf ("%01.2f",$this->SEPA_BETRAG)."</CtrlSum>\n";
  $XML .= "            <InitgPty>\n";
  $XML .= "                <Nm>".substr($this->BASIS_INFO["NAME"],0,70)."</Nm>\n";
  $XML .= "            </InitgPty>\n";
  $XML .= "        </GrpHdr>\n";
  // Hier beginnen die Zahlungsinformationen
  $XML .= "        <PmtInf>\n";
  // Allgemeine Zahlungsinformationen zum gesamten Auftrag
  $XML .= "            <PmtInfId>".substr($this->convert_min_ohne_leerzeichen("PII$this->SEPA_ID"),0,35)."</PmtInfId>\n";
  $XML .= "            <PmtMtd>DD</PmtMtd>\n";
  $XML .= "            <NbOfTxs>".sprintf ("%d",$this->SEPA_ANZAHL)."</NbOfTxs>\n";
  $XML .= "            <CtrlSum>".sprintf ("%01.2f",$this->SEPA_BETRAG)."</CtrlSum>\n";
  $XML .= "            <PmtTpInf>\n";
  $XML .= "                <SvcLvl>\n";
  $XML .= "                    <Cd>SEPA</Cd>\n";
  $XML .= "                </SvcLvl>\n";
  $XML .= "                <LclInstrm>\n";
  $XML .= "                    <Cd>CORE</Cd>\n";
  $XML .= "                </LclInstrm>\n";
  $XML .= "                <SeqTp>".$this->BASIS_INFO["SEQUENZ"]."</SeqTp>\n";
  $XML .= "            </PmtTpInf>\n";
  $XML .= "            <ReqdColltnDt>".date("Y-m-d",strtotime('+9 day'))."</ReqdColltnDt>\n";
  $XML .= "            <Cdtr>\n";
  $XML .= "                <Nm>".$this->BASIS_INFO ["NAME"]."</Nm>\n";
  $XML .= "            </Cdtr>\n";
  $XML .= "            <CdtrAcct>\n";
  $XML .= "                <Id>\n";
  $XML .= "                   <IBAN>".$this->BASIS_INFO["IBAN"]."</IBAN>\n";
  $XML .= "                </Id>\n";
  $XML .= "            </CdtrAcct>\n";
  $XML .= "            <CdtrAgt>\n";
  $XML .= "                <FinInstnId>\n";
  $XML .= "                    <BIC>".$this->BASIS_INFO["BIC"]."</BIC>\n";
  $XML .= "                </FinInstnId>\n";
  $XML .= "            </CdtrAgt>\n";
  $XML .= "            <ChrgBr>".$this->BASIS_INFO["ART"]."</ChrgBr>\n";
  $XML .= "            <CdtrSchmeId>\n";
  $XML .= "                <Id>\n";
  $XML .= "                    <PrvtId>\n";
  $XML .= "                        <Othr>\n";
  $XML .= "                            <Id>".$this->BASIS_INFO["IDENTNR"]."</Id>\n";
  $XML .= "                            <SchmeNm>\n";
  $XML .= "                                <Prtry>SEPA</Prtry>\n";
  $XML .= "                            </SchmeNm>\n";
  $XML .= "                        </Othr>\n";
  $XML .= "                    </PrvtId>\n";
  $XML .= "                </Id>\n";
  $XML .= "            </CdtrSchmeId>\n";
  foreach ($this->SEPA_ZAHLUNG as $key => $inhalt)
  {
    $XML .= "            <DrctDbtTxInf>\n";
    $XML .= "                <PmtId>\n";
    $XML .= "                    <EndToEndId>NOTPROVIDED</EndToEndId>\n";
    $XML .= "                </PmtId>\n";
    $XML .= "                <InstdAmt Ccy=\"EUR\">".$inhalt["BETRAG"]."</InstdAmt>\n";
    $XML .= "                <DrctDbtTx>\n";
    $XML .= "                    <MndtRltdInf>\n";
    $XML .= "                        <MndtId>".$inhalt["MANDANT"]."</MndtId>\n";
    $XML .= "                        <DtOfSgntr>".$inhalt["UNTERSCHRIFT"]."</DtOfSgntr>\n";
    $XML .= "                    </MndtRltdInf>\n";
    $XML .= "                </DrctDbtTx>\n";
    $XML .= "                <DbtrAgt>\n";
    $XML .= "                    <FinInstnId>\n";
    $XML .= "                        <BIC>".$inhalt["BIC"]."</BIC>\n";
    $XML .= "                    </FinInstnId>\n";
    $XML .= "                </DbtrAgt>\n";
    $XML .= "                <Dbtr>\n";
    $XML .= "                    <Nm>".$inhalt["NAME"]."</Nm>\n";
    $XML .= "                </Dbtr>\n";
    $XML .= "                <DbtrAcct>\n";
    $XML .= "                    <Id>\n";
    $XML .= "                        <IBAN>".$inhalt["IBAN"]."</IBAN>\n";
    $XML .= "                    </Id>\n";
    $XML .= "                </DbtrAcct>\n";
    $XML .= "                <RmtInf>\n";
    $XML .= "                    <Ustrd>".$inhalt["VERWENDUNG"]."</Ustrd>\n";
    $XML .= "                </RmtInf>\n";
    $XML .= "            </DrctDbtTxInf>\n";
  }
  // Hier enden die Zahlungsinformationen
  $XML .= "        </PmtInf>\n";
  // Hier endet das SEPA-Dokument
  $XML .= "    </CstmrDrctDbtInitn>\n";
  // Hier endet die XML-Datei
  $XML .= "</Document>\n";
  return($XML);
}

//****f* sepa-xml.inc/bereitstellen ()
// SICHTBAR
//   öffentlich sichtbar
// BESCHREIBUNG
//   Die Funktion stellt die XML-Datei bereit
//****
public function bereitstellen ()
{
  $FNAME = date("Y-m-d")."-".$this->BASIS_INFO["SEQUENZ"]."-".$this->SEPA_ID.".xml";
  $F_ile = fopen ("/tmp/$FNAME","w");
  fwrite ($F_ile,$this->makexml());
  fclose ($F_ile);
  header ("Content-Type: text/plain");
  header ("Content-Disposition: attachment; filename=\"$FNAME\"");
  readfile ("/tmp/$FNAME");
}


} // Ende der Klasse cl_sepa

?>