<?php
//****h* /tabdatei.inc
// KLASSE
//   cl_tabdatei
//     Diese Klasse verwaltet eine TAB-getrennte Textdatei als Tabelle
// HISTORIE
//   08.03.2011 Umstellung auf PHP5-Klassenstruktur
//   15.12.2007 Klasse erstellt
// BUGS
//   keine bekannt
//****

//****c* tabdatei.inc/cl_tabdatei
class cl_tabdatei
{
// VARIABLE
//    Name                privat  Inhalt
//    -------------------------------------------------------------------------
//    $F_ilename          ja      Dateiname incl. Pfad der TAB-Datei
  private $F_ilename;
//    $I_nhalt            ja      Array mit dem Inhalt der TAB-Datei
  private $I_nhalt;
//    $A_nzahl            nein    Anzahl der Tabellen-Zeilen
  public $A_nzahl;
//    $H_eader            ja      Kopfzeile ja/nein - > wenn ja, dann ist die
//                                erste Zeile die Kopfzeile
  private $H_eader;
//    $H_inhalt           ja      Inhalt der Kopfzeile
  private $H_inhalt;
//****

//****f* cl_tabdatei/readfile ()
// NAME
//   readfile ()
// SICHTBAR
//   Nur innerhalb der Klasse
// BESCHREIBUNG
//   Oeffnet die Datei und liest die Daten in das interne Array $I_nhalt ein
//   Wenn die Datei nicht existert, wird eine neue Datei angelegt.
//****
private function readfile ()
{
  $this->A_nzahl   = 0;
  $K_OPF = $this->H_eader;
  if (file_exists ($this->F_ilename))
  {
    $F = fopen ($this->F_ilename, "r");
  }
  else
  {
    $F = fopen ($this->F_ilename,"w");
    fclose ($F);
    $F = fopen ($this->F_ilename, "r");
  }
  while (! feof ($F))
  {
    $S = trim(fgets ($F,1024));
    if (! empty ($S))
    {
      if($K_OPF)
      {
        $this->H_inhalt = explode("\t",$S);
        $K_OPF = false;
      }
      else
      {
        $this->I_nhalt[$this->A_nzahl] = explode ("\t",$S);
        $this->A_nzahl++;
      }
    }
  }
  fclose ($F);
}

//****f* cl_tabdatei/cl_tabdatei (Pfad zur Datei, Kopfzeile)
// NAME
//   cl_tabdatei ($name,$kopfzeile)
//     $name      = Pfad zur TAB-Datei
//     $kopfzeile = Datei enthaelt eine Spaltenueberschrift?
//                  true   = Spaltenueberschrift vorhanden
//                  false  = keine Spaltenueberschrift
//
//   Konstruktor der Klasse
// BESCHREIBUNG
//   Konstruktor der Klasse
//****
function __construct ($name, $kopfzeile = false)
{
  $this->F_ilename = $name;
  $this->H_eader   = $kopfzeile;
  $this->readfile();
}

//****f* cl_tabdatei/tab_sort ()
// NAME
//   tab_sort
//     Sortiert die TAB-Datei nach dem Inhalt der 1. Spalte
// SICHTBAR
//   public
//****
public function tab_sort ()
{
  sort ($this->I_nhalt);
}

//****f* cl_tabdatei/tab_save ()
// NAME
//   tab_save
//   Speichert die geaenderten Daten und liest die Datei anschliessend neu ein
// SICHTBAR
//   public
//****
public function tab_save ()
{
  $F = fopen ($this->F_ilename,"w");
  if ($this->H_eader)
  {
    $e = count ($this->H_inhalt);
    $x = 0; while ($x < $e)
    {
      fwrite ($F,$this->H_inhalt[$x]);
      $x++;
      if ($x < $e) fwrite ($F,"\t");
    }
    fwrite($F,"\n");
  }
  $i = 0; while ($i < $this->A_nzahl)
  {
    $e = count ($this->I_nhalt[$i]);
    $x = 0; while ($x < $e)
    {
      fwrite ($F,$this->I_nhalt[$i][$x]);
      $x++;
      if ($x < $e) fwrite ($F,"\t");
    }
    if ($i < $this->A_nzahl) fwrite ($F,"\n");
    $i++;
  }
  fclose ($F);
  unset ($this->I_nhalt);
  unset ($this->H_inhalt);
  $this->readfile ();
}

//****f* cl_tabdatei/tab_set (Zeilen-Nr., Feld, Neuer Feldinhalt)
// NAME
//   tab_set ($nr, $feld, $feldinhalt)
//   Traegt ein Feld in die Datenbank ein
//     $nr         Zeilen-Nr. beginnt mit 0 -> wenn groesser als $A_nzahl, dann
//                 erfolgt ein Neueintrag, ansonsten wird der betroffene Datensatz
//                 ueberschrieben
//     $feld       Spalte, die eingetragen werden soll
//     $feldinhalt Inhalt des Datenbankfeldes
// SICHTBAR
//   public
// ERGEBNIS
//   Wenn eine Kopfzeile in der Datei enthalten ist wird die durch $feld definierte
//   Spalte der Kopfzeile auf $feldinhalt gesetzt wenn $nr < 0 ist
//   Ansonsten wird in Spalte $feld und Zeile $nr der durch $feldinhalt angegebene
//   Wert eingetragen.
//****
public function tab_set ($nr,$feld,$feldinhalt)
{
  if ($this->H_eader and ($nr < 0))
  {
    $this->H_inhalt[$feld] = $feldinhalt;
  }
  else
  {
    if ($nr >= $this->A_nzahl)
    {
      $nr = $this->A_nzahl;
      $this->A_nzahl++;
    }
    $this->I_nhalt[$nr][$feld] = $feldinhalt;
  }
}

//****f* cl_tabdatei/tab_set_by_search (Suchfeld, gesuchter Inhalt, Zielfeld, Feldinhalt)
// NAME
//   tab_set_by_search ($suchfeld, $suche, $zielfeld, $feldinhalt)
//   Traegt ein Feld abhaengig vom Suchergebnis ein.
//     $suchfeld      Spalten-Nr. des gesuchten Feldes
//     $suche         gesuchter Feldinhalt
//     $zielfeld      Spalten-Nr. des einzutragenden Feldes
//     $feldinhalt    einzutragender Feldinhalt
//
//   Wenn die Suche mehrere Treffer ergibt, wird das Feld in allen betroffenen
//   Feldern eingetragen. Wenn es keine Treffer gibt wird eine neue Zeile ein-
//   getragen.
// SICHTBAR
//   public
//****
public function tab_set_by_search ($suchfeld, $suche, $zielfeld, $feldinhalt)
{
  $gefunden = 0;
  $i = 0; while ($i < $this->A_nzahl)
  {
    if ($this->I_nhalt[$i][$suchfeld] == $suche)
    {
      $this->tab_set ($i,$zielfeld,$feldinhalt);
      $gefunden = 1;
    }
    $i++;
  }
  if ($gefunden == 0) $this->tab_set($this->A_nzahl,$zielfeld,$feldinhalt);
}

//****f* cl_tabdatei/tab_get (Suchfeld, gesuchter Inhalt, Ergebnisfeld)
// NAME
//   tab_get ($suchfeld, $suche, $ergebnisfeld)
//   Holt ein Feld abhaengig vom Suchergebnis aus der Datenbank
//     $suchfeld      Spalten-Nr. des gesuchten Feldes
//     $suche         gesuchter Feldinhalt
//     $ergebnisfeld  Spalten-Nr. des zu holenden Feldes
//
//   Es wird nur das letzte gefundene Feld zurueck gegeben
// SICHTBAR
//   public
//****
public function tab_get ($suchfeld, $suche, $ergebnisfeld)
{
  $ret = "";
  $i = 0; while ($i < $this->A_nzahl)
  {
    $ret = ($this->I_nhalt[$i][$suchfeld] == $suche)
         ? $this->I_nhalt[$i][$ergebnisfeld]
         : $ret;
    $i++;
  }
  return ($ret);
}

//****f* cl_tabdatei/tab_getmulti (Suchfeld, gesuchter Inhalt)
// NAME
//   tab_getmulti ($suchfeld, $suche)
//   Durchsucht die Datenbank
//     $suchfeld      Spalten-Nr. des gesuchten Feldes
//     $suche         gesuchter Feldinhalt
//
//   Es wird ein Array mit den Zeilen-Nr. der gefundenen Felder zurueck gegeben
//   Im Element 0 steht zusaetzlich die Anzahl der gefundenen Felder
// SICHTBAR
//   public
//****
public function tab_getmulti ($suchfeld, $suche)
{
  $ret [0] = 0;
  $i = 0; while ($i < $this->A_nzahl)
  {
    if ($this->I_nhalt[$i][$suchfeld] == $suche)
    {
      $anz       = $ret[0] + 1;
      $ret[0]    = $anz;
      $ret[$anz] = $i;
    }
    $i++;
  }
  return ($ret);
}

//****f* cl_tabdatei/tab_by_nr (Zeilen-Nr., Ergebnisfeld)
// NAME
//   tab_by_nr ($nr, $ergebnisfeld)
//   Holt ein Feld aus der Datenbank
//     $nr            Zeilen-Nr.
//     $ergebnisfeld  Spalten-Nr.
// SICHTBAR
//   public
//****
public function tab_by_nr ($nr,$ergebnisfeld)
{
  return ($this->I_nhalt[$nr][$ergebnisfeld]);
}

//****f* cl_tabdatei/tab_header ()
// NAME
//   tab_header ()
//   Gibt die Kopfzeile als Array zurueck. Wenn es sich um ein Datei ohne
//   Kopfzeile handelt, wird NULL zurueckgegeben
// SICHTBAR
//   public
//****
public function tab_header ()
{
  if ($this->H_eader) return ($this->H_inhalt);
  else                return (NULL);
}

}// Ende der Klasse

?>