<?php
//****M* Datenbank-Klasse/Tabelle: virtual_konto +003+
// NAME
//   php/klassen/uverein-database.003.inc
// KLASSE 
//   cl_uverein_database_003
//   Klasse fuer den Zugriff auf die Tabelle virtual_konto
// ABHAENGIG VON
//   Klasse                   Datei                    Hinweis
//   ---------------------------------------------------------------------
//   cl_database              database.inc             Datenbank-Klasse
//   cl_uverein_database_001  uverein-database.001.inc Basis-Informationen
//   cl_uverein_database_002  uverein-database.002.inc bu_konten
//   PHP 5
// BESCHREIBUNG
//   Schluessel          Funktion           Kommentar
//   ---------------------------------------------------------------------
//   BEITRAG             get_vbeitrag       Daten fuer die Zuordnung der
//                       set_vbeitrag       Beitragszahlungen
//   SOLLBEITRAG         get_vsollbeitrag   Letzte Buchung des Beitrags-
//                       set_vsollbeitrag   solls
//   FINANZKONTO         get_vfinanz        Welche Kontenart haben die
//                       set_vfinanz        Finanzkonten?
//   SCHWEBEKONTO        get_vschwebe       Schwebekonto
//                       set_vschwebe
//   UEBERTRAG           get_vuebertrag     Daten fuer den Uebertrag
//                       set_vuebertrag
//   VORSTEUER           get_vsteuer        Daten fuer die Vorsteuer-
//                       set_vsteuer        Buchung    
// HISTORIE
//   06.06.2010 Beitragsrueckstand ergaenzt
//   10.01.2010 Fehler beim uebermitteln von 0-Werten korrigiert
//   03.01.2010 Beitragseinzug integriert
//   31.05.2009 Bug bei set_vfinanz bereinigt -> break entfernt
//              Bug bei set_vschwebe bereinigt -> break entfernt
//   10.04.2009 Klasse erstellt
// AUTOR
//   Uwe Schied
// BUGS
//   keine bekannt
//****

include_once (dirname (__FILE__) . "/uverein-database.002.inc");

class cl_uverein_database_003 extends cl_uverein_database_002 { 
function __construct($name, $schema = "public") 
{
   parent::__construct ($name,$schema);
}                      

//
// Interne Konstanten
//
private $KEY_BEITRAG          = "BEITRAG";
private $KEY_ERINNERUNG_1     = "BEITRAG_1";
private $KEY_ERINNERUNG_2     = "BEITRAG_2";
private $KEY_ERINNERUNG_3     = "BEITRAG_3";
private $KEY_LEVRETOURE       = "BEITRAG_LEV";
private $KEY_FINANZKONTO      = "FINANZKONTO";
private $KEY_SCHWEBEKONTO     = "SCHWEBEKONTO";
private $KEY_UEBERTRAG        = "UEBERTRAG";
private $KEY_VORSTEUER        = "VORSTEUER";

//****f* Tabelle: virtual_konto +003+/intern_eintragen 
// FUNCTION
//   intern_eintragen   Zuordnung eintragen
// GENUTZT VON
//   Diese Funktion ist nur klassenintern verfuegbar
// ERGEBNIS
//   Die Zuordnung wurde entweder neu eingetragen oder aktualisiert
//****
private function intern_eintragen ($art,$konto  = "",$fkonto = "",$kst    = "")
{
  // Pruefen ob die Zurordnung bereits vorhanden ist
  $this->sql_befehl ("SELECT * FROM virtual_konto".
                     " WHERE verein='$this->SET_VEREIN' AND art='$art'");
  if ($this->sql_lines() > 0) // UPDATE erforderlich
  {
    $SET  = "art='$art'";
    $SET .= ($konto == "")  ? "" : ", konto='$konto'";
    $SET .= ($fkonto == "") ? "" : ", fkonto='$fkonto'";
    $SET .= ($kst == "")    ? "" : ", kst='$kst'";
    $this->sql_befehl ("UPDATE virtual_konto SET $SET".
                       " WHERE art='$art' AND verein='$this->SET_VEREIN'");   
  }
  else // Neueintrag
  {
    $SET  = ($konto == "")  ? "'0'" : "'$konto'";
    $SET .= ",";
    $SET .= ($fkonto == "") ? "'0'" : "'$fkonto'";
    $SET .= ",";
    $SET .= ($kst == "")    ? "'0'" : "'$kst'";
    $this->sql_befehl ("INSERT INTO virtual_konto".
                       " (verein,art,konto,fkonto,kst)".
                       " VALUES ('$this->SET_VEREIN','$art',$SET)");
  }
} 

//****f* Tabelle: virtual_konto +003+/intern_holen 
// FUNCTION
//   intern_holen   Feld auslesen 
// GENUTZT VON
//   Diese Funktion ist nur klassenintern verfuegbar
// ERGEBNIS
//   Es wird der Feldinhalt zurueck geliefert
//****
private function intern_holen ($art,$spalte)
{
  $RET = $this->sql_1_value("virtual_konto",$spalte,
                            "verein='$this->SET_VEREIN' AND art='$art'");
  $RET = ($RET == "") ? 0 : $RET;  
  return ($RET);
}

//****f* Tabelle: virtual_konto +003+/get_vbeitrag (Feldbezeichnung)
// FUNCTION
//   get_vbeitrag   Zuordnungen zur Beitragszahlung lesen
//   $feld          Welches Feld soll ausgelesen werden
//     Moegliche Werte:
//     KONTO  Beitragskonto fuer die Buchhaltung = Voreinstellung
//     FINANZ Finanzkonto fuer die Voreinstellung in der Mitgliederverwaltung
//     KST    Kostenstelle fuer die Beitragsbuchungen
// ERGEBNIS
//   Es wird die gewuenschte Informationen zurueck gegeben
//****
public function get_vbeitrag ($feld = "")
{
  switch ($feld)
  {
    case 'FINANZ' : $feld = "fkonto"; break;
    case 'KST'    : $feld = "kst";    break;
    default :       $feld = "konto";  break;
  }
  return ($this->intern_holen($this->KEY_BEITRAG,$feld));
} 

//****f* Tabelle: virtual_konto +003+/set_vbeitrag (Wert, Feldbezeichnung)
// FUNCTION
//   set_vbeitrag   Zuordnungen zur Beitragszahltung setzen
//   $wert          Welcher Wert soll eingetragen werden
//   $feld          Welches Feld soll ausgelesen werden
//     Moegliche Werte:
//     KONTO  Beitragskonto fuer die Buchhaltung = Voreinstellung
//     FINANZ Finanzkonto fuer die Voreinstellung in der Mitgliederverwaltung
//     KST    Kostenstelle fuer die Beitragsbuchungen
// ERGEBNIS
//   Es wird die gewuenschte Aenderung in die Tabelle geschrieben
//****

public function set_vbeitrag ($wert,$feld = "")
{
  $wert = ($wert >= 0) ? $wert : "0";  // keine negative Werte
  switch ($feld)
  {
    case 'FINANZ' : $this->intern_eintragen ($this->KEY_BEITRAG,"",$wert);    break;
    case 'KST'    : $this->intern_eintragen ($this->KEY_BEITRAG,"","",$wert); break;
    default :       $this->intern_eintragen ($this->KEY_BEITRAG,$wert);       break;
  }
} 

//****f* Tabelle: virtual_konto +003+/get_sollbeitrag ()
// FUNCTION
//   get_vsollbeitrag  liefert das Datum des letzten Beitragseinzuges im 
//                     Format JJJJMMTT
// ERGEBNIS
//   Es wird das Datum der letzten automatischen Beuchung des Soll-Beitrages
//   Ist noch keine automatische Buchung erfolgt, wird 0 zurueck geliefert.
//****
public function get_vsollbeitrag ()
{
  $data = $this->intern_holen("SOLLBEITRAG","konto");
  $data = (empty($data)) ? 0 : $data;
  return ($data);
} 

//****f* Tabelle: virtual_konto +003+/set_vsollbeitrag ()
// FUNCTION
//   set_vsollbeitrag  Setzt das Datum der letzten automatischen Buchung
//                     des Soll-Beitrages im Format JJJJMMTT
//****
public function set_vsollbeitrag ()
{
  $this->intern_eintragen ("SOLLBEITRAG",date("Ymd"));
} 

//****f* Tabelle: virtual_konto +003+/get_vfinanz ()
// FUNCTION
//   get_vfinanz   Kontenart der Finanzkonten
// ERGEBNIS
//   Es wird die gewuenschte Informationen zurueck gegeben
//****
public function get_vfinanz ()
{
  return ($this->intern_holen($this->KEY_FINANZKONTO,"konto"));
} 

//****f* Tabelle: virtual_konto +003+/set_vfinanz (Kontenart)
// FUNCTION
//   set_vfinanz   Kontenart der Finanzkonten
// ERGEBNIS
//   Es wird die gewuenschte Aenderung in die Tabelle geschrieben
//****
public function set_vfinanz ($wert)
{
  $wert = ($wert >= 0) ? $wert : "0";  // keine negative Werte
  $this->intern_eintragen ($this->KEY_FINANZKONTO,$wert);
} 

//****f* Tabelle: virtual_konto +003+/get_vschwebe ()
// FUNCTION
//   get_vschwebe   Konto-Nr. des Schwebekontos
// ERGEBNIS
//   Es wird die gewuenschte Informationen zurueck gegeben
//****
public function get_vschwebe ()
{
  return ($this->intern_holen($this->KEY_SCHWEBEKONTO,"konto"));
} 

//****f* Tabelle: virtual_konto +003+/set_vschwebe (Konto-Nr)
// FUNCTION
//   set_vschwebe   Konto-Nr. des Schwebekontos
// ERGEBNIS
//   Es wird die gewuenschte Aenderung in die Tabelle geschrieben
//****
public function set_vschwebe ($wert)
{
  $wert = ($wert >= 0) ? $wert : "0";  // keine negative Werte
  $this->intern_eintragen ($this->KEY_SCHWEBEKONTO,$wert);
} 

//****f* Tabelle: virtual_konto +003+/get_vuebertrag (Feldbezeichnung)
// FUNCTION
//   get_vuebertrag Zuordnungen fuer den Uebertrag 
//   $feld          Welches Feld soll ausgelesen werden
//     Moegliche Werte:
//     KLASSE Kontenart = Voreinstellung
//     FINANZ Finanzkonto
//     KST    Kostenstelle
// ERGEBNIS
//   Es wird die gewuenschte Informationen zurueck gegeben
//****
public function get_vuebertrag ($feld = "")
{
  switch ($feld)
  {
    case 'FINANZ' : $feld = "fkonto"; break;
    case 'KST'    : $feld = "kst";    break;
    default :       $feld = "konto";  break;
  }
  return ($this->intern_holen($this->KEY_UEBERTRAG,$feld));
} 

//****f* Tabelle: virtual_konto +003+/set_vuebertrag (Wert, Feldbezeichnung)
// FUNCTION
//   set_vuebertrag Zuordnungen fuer den Uebertrag
//   $wert          Welcher Wert soll eingetragen werden
//   $feld          Welches Feld soll ausgelesen werden
//     Moegliche Werte:
//     KLASSE Kontenart
//     FINANZ Finanzkonto
//     KST    Kostenstelle
// ERGEBNIS
//   Es wird die gewuenschte Aenderung in die Tabelle geschrieben
//****
public function set_vuebertrag ($wert,$feld = "")
{
  $wert = ($wert >= 0) ? $wert : "0";  // keine negative Werte
  switch ($feld)
  {
    case 'FINANZ' : $this->intern_eintragen ($this->KEY_UEBERTRAG,"",$wert);    break;
    case 'KST'    : $this->intern_eintragen ($this->KEY_UEBERTRAG,"","",$wert); break;
    default :       $this->intern_eintragen ($this->KEY_UEBERTRAG,$wert);       break;
  }
} 

//****f* Tabelle: virtual_konto +003+/get_vsteuer (Feldbezeichnung)
// FUNCTION
//   get_vsteuer    Zuordnungen des Vorsteuer-Kontos 
//   $feld          Welches Feld soll ausgelesen werden
//     Moegliche Werte:
//     KONTO  Vorsteuerkonto-Nr = Voreinstellung
//     FINANZ Finanzkonto fuer die Vorsteuer
//     KST    Kostenstelle
// ERGEBNIS
//   Es wird die gewuenschte Informationen zurueck gegeben
//****
public function get_vsteuer ($feld = "")
{
  switch ($feld)
  {
    case 'FINANZ' : $feld = "fkonto"; break;
    case 'KST'    : $feld = "kst";    break;
    default :       $feld = "konto";  break;
  }
  return ($this->intern_holen($this->KEY_VORSTEUER,$feld));
} 

//****f* Tabelle: virtual_konto +003+/set_vsteuer (Wert, Feldbezeichnung)
// FUNCTION
//   set_vsteuer    Zuordnungen des Vorsteuer-Kontos
//   $wert          Welcher Wert soll eingetragen werden
//   $feld          Welches Feld soll ausgelesen werden
//     Moegliche Werte:
//     KONTO  Vorsteuerkonto-Nr = Voreinstellung
//     FINANZ Finanzkonto fuer die Vorsteuer
//     KST    Kostenstelle
// ERGEBNIS
//   Es wird die gewuenschte Aenderung in die Tabelle geschrieben
//****
public function set_vsteuer ($wert,$feld = "")
{
  $wert = ($wert >= 0) ? $wert : "0";  // keine negative Werte
  switch ($feld)
  {
    case 'FINANZ' : $this->intern_eintragen ($this->KEY_VORSTEUER,"",$wert);    break;
    case 'KST'    : $this->intern_eintragen ($this->KEY_VORSTEUER,"","",$wert); break;
    default :       $this->intern_eintragen ($this->KEY_VORSTEUER,$wert);       break;
  }
} 

//****f* Tabelle: virtual_konto +003+/get_vmahnbrief (Feld)
// FUNCTION
//   get_vmahnbrief Mahnbrief holen 
//   Feld    Welche Mahnung soll geholt werden?
//     Moegliche Werte:
//     1    = 1. Erinnerung
//     2    = 2. Erinnerung
//     3    = 3. Erinnerung 
//     99   = Lastschriftretoure
// ERGEBNIS
//   Der gewuenschte Brief wird zurueckgeliefert
//****
public function get_mahnbrief ($feld)
{
  switch ($feld)
  {
    case 1  : $art = $this->KEY_ERINNERUNG_1; break;
    case 2  : $art = $this->KEY_ERINNERUNG_2; break;
    case 3  : $art = $this->KEY_ERINNERUNG_3; break;
    case 99 : $art = $this->KEY_LEVRETOURE;   break;
  }
  $feld = $this->intern_holen($art,"konto");
  return ($this->sql_1_value("briefe","inhalt",
                             "verein='$this->SET_VEREIN' AND nr='$feld'"));
} 

//****f* Tabelle: virtual_konto +003+/get_vmahngebuehr (Feld)
// FUNCTION
//   get_vmahngebuehr Hoehe der Mahnkosten holen 
//   Feld    Welche Mahnung soll geholt werden?
//     Moegliche Werte:
//     1    = 1. Erinnerung
//     2    = 2. Erinnerung
//     3    = 3. Erinnerung 
//     99   = Lastschriftretoure
// ERGEBNIS
//   Der gewuenschte Gebuher wird zurueckgeliefert
//****
public function get_mahngebuehr ($feld)
{
  switch ($feld)
  {
    case 1  : $art = $this->KEY_ERINNERUNG_1; break;
    case 2  : $art = $this->KEY_ERINNERUNG_2; break;
    case 3  : $art = $this->KEY_ERINNERUNG_3; break;
    case 99 : $art = $this->KEY_LEVRETOURE;   break;
  }
  $feld = $this->intern_holen($art,"fkonto") + 0;
  return($feld);
} 

//****f* Tabelle: virtual_konto +003+/set_vmahnung (Art,Wert,Feld)
// FUNCTION
//   set_vmahnung   Mahnbriefe und -kosten verwalten
//   Art   Art der Mahnung
//     1    = 1. Erinnerung
//     2    = 2. Erinnerung
//     3    = 3. Erinnerung 
//     99   = Lastschriftretoure
//   Wert  Welcher Wert soll eingetragen werden
//   Feld  Welches Feld soll ausgelesen werden
//     Moegliche Werte:
//     BRIEF   Nr. des Briefes aus der Tabelle "briefe"
//     GEBUEHR Hoehe der Mahngebuehr
// ERGEBNIS
//   Es wird die gewuenschte Aenderung in die Tabelle geschrieben
//****
public function set_vmahnung ($art,$wert,$feld)
{
  $wert = ($wert >= 0) ? $wert : "0";  // keine negative Werte
  switch ($art)
  {
    case 1  : $art = $this->KEY_ERINNERUNG_1; break;
    case 2  : $art = $this->KEY_ERINNERUNG_2; break;
    case 3  : $art = $this->KEY_ERINNERUNG_3; break;
    case 99 : $art = $this->KEY_LEVRETOURE;   break;
  }
  switch (strtoupper($feld))
  {
    case 'BRIEF'   : $this->intern_eintragen ($art,$wert);    break;
    case 'GEBUEHR' : $this->intern_eintragen ($art,"",$wert); break;
  }
} 
} // ENDE der Klasse

?>