<?php
//****M* Datenbank-Klasse/Tabelle: beitrag +005+
// NAME
//   php/klassen/uverein-database.005.inc
// KLASSE 
//   cl_uverein_database_005
//   Klasse fuer den Zugriff auf die Beitragsbuchungen
// ABHAENGIG VON
//   Klasse                   Datei                    Hinweis
//   ---------------------------------------------------------------------
//   cl_database              database.inc             Datenbank-Klasse
//   cl_uverein_database_001  uverein-database.001.inc Basis-Informationen
//   cl_uverein_database_002  uverein-database.002.inc bu_konten
//   cl_uverein_database_003  uverein-database.003.inc virtual_konto
//   cl_uverein_database_004  uverein-database.004.inc bu_belege
//   PHP 5
// BESCHREIBUNG
//
// HISTORIE
//   06.01.2010 Klasse erstellt
// AUTOR
//   Uwe Schied
// BUGS
//   keine bekannt
//****

include_once (dirname (__FILE__) . "/test-log.inc");

include_once (dirname (__FILE__) . "/uverein-database.004.inc");
class cl_uverein_database_005 extends cl_uverein_database_004 { 
function __construct($name, $schema = "public") 
{
   parent::__construct ($name,$schema);
   $this->error_name (CL_DATABASE_ERROR_005_INSERT,"INSERT-ERROR of posting membership fee");
}

//****f* Tabelle: beitrag +005+/test_log
// FUNCTION
//   test_log
//   Diese Funktion ist Klassen-Intern definiert und außerhalb der Klasse nicht 
//   aufrufbar.
//****
private function testlog ($func, $inhalt)
{
  test_log ("cl_uverein_database_005->$func");
  test_log ("$inhalt");
  test_log ("ERRORCODE = $this->ERRORCODE");
  test_log ("ERRORTEXT = ".$this->error_text());
  test_log (" ------------------------ ");
}

//****f* Tabelle: beitrag +005+/beitrag_insert
// FUNCTION
//   beitrag_insert  Beitragsbuchung erfassen
//     $nr           Mitglieds-Nr
//     $datum        Buchungsdatum
//     $text         Buchungstext
//     $haben        Betrag fuer die Haben-Buchung (Voreinstellung 0)
//     $soll         Betrag fuer die Soll-Buchung (Voreinstellung 0)
//     $konto        Finanzkonto fuer die Buchung
//                   optional -> wenn leer, wird das Konto aus virtual_konto
//                   ermittelt 
// BEISPIEL
//   $UVEREIN_DB->beitrag_insert ("1","31.12.2009","Ueberweisung","20");
//      = Habenbuchung ist auf Standard-Finanzkonto eingegangen
//   $UVEREIN_DB->beitrag_insert ("1","01.01.2010","Jahresbeitrag","0","20");
//      = Beitragssoll gebucht
// ERGEBNIS
//   Buchung wird ins Beitragskonto eingetragen.
//   im Fehlerfall wird CL_DATABASE_ERROR_005_INSERT in $ERRORCODE zurueckgeliefert
//****
public function beitrag_insert ($nr,$datum,$text,$haben = 0,$soll = 0,$konto=-1)
{
  $konto = ($konto == -1) ? $this->get_vbeitrag ("FINANZ") : $konto;
  $BEFEHL = "INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text)".
            " VALUES ('$this->SET_VEREIN','$nr','$this->SET_JAHR','$konto','$datum',".
                     "'$soll','$haben','$text');"; 
  $this->sql_befehl ($BEFEHL);
  $this->ERRORCODE = ($this->ERRORCODE == CL_DATABASE_OK) ? CL_DATABASE_OK : CL_DATABASE_ERROR_005_INSERT;
//  $this->testlog ("beitrag_insert",$BEFEHL);
} 

//****f* Tabelle: beitrag +005+/get_beitragfaellig
// FUNCTION
//   get_beitragfaellig Beitragsfaelligkeit als Array holen
//     $nr              Nr. aus der Tabelle beitrags_konto
// ERGEBNIS
//   Es wird ein Array zuruckgeliefert, das folgende KEYs enthaellt:
//     KEY          Inhalt
//     --------------------------------------------------------------
//     TAG          Tag der 1. Faelligkeit
//     MONAT        Monat der 1. Faelligkeit
//     JAHR         Jahr der 1. Faelligkeit
//****
public function get_beitragfaellig ($nr)
{
  $was = "EXTRACT(DAY FROM faellig_ab)";
  $FAELLIG["TAG"]   = $this->sql_1_value("beitrags_konto",$was,"nr='$nr'");
  $was = "EXTRACT(MONTH FROM faellig_ab)";
  $FAELLIG["MONAT"] = $this->sql_1_value("beitrags_konto",$was,"nr='$nr'");
  $was = "EXTRACT(YEAR FROM faellig_ab)";
  $FAELLIG["JAHR"]  = $this->sql_1_value("beitrags_konto",$was,"nr='$nr'");  
  return ($FAELLIG);
}

//****f* Tabelle: beitrag +005+/get_beitragstext
// FUNCTION
//   get_beitragstext Beitragsart als Text holen
//     $nr           Nr. der Beitragsart aus Tabelle beitrags_art
//****
public function get_beitragstext ($nr)
{
  return ($this->sql_1_value("beitrags_art","art","nr='$nr'"));
} 

//****f* Tabelle: beitrag +005+/get_beitragshoehe
// FUNCTION
//   get_beitragshoehe Hoehe des Jahresbeitrages holen
//     $nr             Nr. der Beitragsart aus Tabelle beitrags_art
//****
public function get_beitragshoehe ($nr)
{
  return ($this->sql_1_value("beitrags_art","jahresbeitrag","nr='$nr'")+0);
} 

//****f* Tabelle: beitrag +005+/get_beitraege
// FUNCTION
//   get_beitraege 
//     $SUM    summierte Ausgabe?
//       true  die Zahlungen werden pro Finanzkonto summiert 
//       false es werden alle Zahlungen zurueckgeliefert
// VOREINSTELLUNG
//   true
// ERGEBNIS
//   Liefert einen Zeiger auf die Beitragszahlungen des aktuellen Jahres
//****
public function get_beitraege ($SUM = true)
{
	if ($SUM)
	{
	  $this->sql_befehl ("SELECT f_konto, sum(haben) AS haben FROM beitrag ".
	                     "WHERE v_name='".$this->get_verein()."'".
	                     "  AND jahr='".$this->get_jahr()."'".
	                     " GROUP BY f_konto ORDER BY f_konto");
   }	
	else
	{
	  $this->sql_befehl ("SELECT f_konto, datum, haben,".
	                     "       name || ',' || vorname || ': ' || bu_text AS info".
	                     "  FROM beitrag,personen".
	                     " WHERE v_name='".$this->get_verein()."'".
	                     "  AND jahr='".$this->get_jahr()."'".
	                     "  AND haben!=0.00" .
	                     "  AND personen.nr=beitrag.m_nr".
	                     " ORDER BY datum,name,vorname");
	}
}

} // ENDE der Klasse

?>