<?php
//****h* /uvereinpdf.inc
// BESCHREIBUNG
//   Erstellt PDF-Dokumente fuer das Projekt uverein
// ABHAENGIG VON
//   php-fpdf      http://www.fpdf.org
// HISTORIE
//   13.04.2008 Tabellenanzeige eingefuegt
//   12.04.2008 Klasse angelegt
// ABHAENGIG VON
//   php-fpdf
//****
require ("fpdf/fpdf.php");

// --------------------------------------------------------
// Konstanten
// --------------------------------------------------------
define ('CL_UVEREINPDF_TABSPALTEN',       0);    // Anzahl der Tabellenspalten
define ('CL_UVEREINPDF_TABSCHRIFT',       1);    // Tabellen-Schriftart, z.B. Arial
define ('CL_UVEREINPDF_TABSCHRIFTGROESSE',2);    // Tabellen-Schriftgroesse
define ('CL_UVEREINPDF_TABSPALTENBREITE', 3);    // Spaltenbreite jeder einzelnen Spalte
define ('CL_UVEREINPDF_TABRAHMEN',        4);    // Rahmen um die Tabelle ?
define ('CL_UVEREINPDF_TABAUSRICHTUNG',   5);    // Ausrichtung jeder einzelnen Spalte

class cl_uvereinpdf extends FPDF
{

var $TabColor;             // Hintergrundfarbe der Tabellenzeile
var $NewPage;              // Seitenwechsel anzeigen
var $SetTempDir;           // Pfad zum temporaeren Verzeichnis
var $PDFName;              // Name des temporaeren Dateinamens
var $Tabelle;              // Array mit Tabelleneigenschaften

// ------------------------------------------------------------------
// Nicht darstellbare Zeichen in darstellbare konvertieren (intern)
// ------------------------------------------------------------------
function uvereinpdf_caseconvert ($S_OLD)
{
  $S_OLD = str_replace ("&auml;" ,"ä",$S_OLD);
  $S_OLD = str_replace ("&Auml;" ,"Ä",$S_OLD);
  $S_OLD = str_replace ("&ouml;" ,"ö",$S_OLD);
  $S_OLD = str_replace ("&Ouml;" ,"Ö",$S_OLD);
  $S_OLD = str_replace ("&uuml;" ,"ü",$S_OLD);
  $S_OLD = str_replace ("&Uuml;" ,"Ü",$S_OLD);
  $S_OLD = str_replace ("&szlig;","ß",$S_OLD);
  $S_OLD = str_replace ("ä",chr(228),$S_OLD);
  $S_OLD = str_replace ("Ä",chr(196),$S_OLD);
  $S_OLD = str_replace ("ö",chr(246),$S_OLD);
  $S_OLD = str_replace ("Ö",chr(214),$S_OLD);
  $S_OLD = str_replace ("ü",chr(252),$S_OLD);
  $S_OLD = str_replace ("Ü",chr(220),$S_OLD);
  $S_OLD = str_replace ("ß",chr(223),$S_OLD);
  $S_OLD = str_replace ("�",chr(252),$S_OLD);
  return ($S_OLD);
}

// ------------------------------------------------------------------
// Kopfzeile - wird automatisch von FPDF aufgerufen
// ------------------------------------------------------------------
function Header ()
{
  if ($this->SetHeader != "")
  {
    $this->SetY (10);
    $this->SetFont ('Arial','',20);
    $this->SetTextColor (0);
    $this->SetFillColor (220);
    $this->SetHeader = $this->uvereinpdf_caseconvert($this->SetHeader);
    $this->Cell (0,10,$this->SetHeader,0,1,'C',1);
  }
}

// ------------------------------------------------------------------
// Fusszeile - wird automatisch von FPDF aufgerufen
// ------------------------------------------------------------------
function Footer ()
{
  $OK = ($this->SetFooter != "") ? true : false;
  $OK = ($this->PageNo() > 1) ? true : $OK;
  if ($OK == true) {   
    $this->SetLineWidth (0.1);
    $this->AliasNbPages ('{MS}');
    $this->SetY(-15);
    $this->SetFont ('Arial','',8);
    $this->SetTextColor (127,127,127);
    $this->SetFooter = $this->uvereinpdf_caseconvert($this->SetFooter);
    $this->Cell (0,5,$this->SetFooter,'T',0,'L');
    $this->SetFont ('Arial','',10);
    $this->Cell (0,5,$this->PageNo() . "/{MS}",'T',1,'R');
  }
  $this->NewPage = true;
}

// ------------------------------------------------------------------
// Tabellenfunktionen
// ------------------------------------------------------------------

//
// Initialisieren
//

//****f* uvereinpdf.inc/table_init
// FUNCTION
//   function table_init (Spalten, Schrift, Schriftgroesse, Rahmenbreite,
//                        Spaltenbreiten, Spaltenausrichtungen)
//   Die Funktion legt die Grundwerte fuer die PDF-Tabelle fest und be-
//   rechnet die Spaltenbreiten anhand der uebergebenen Parameter
//
//   Spalten              = Anzahl der Tabellen-Spalten
//   Schrift              = Schriftart (z.B. Arial)
//   Schriftgroesse       = Schriftgroesse in Punkt
//   Rahmenbreite         = Optionale Breite des Tabellen-Rahmens -
//                          Vorgabe ist 0 -> kein Rahmen
//   Spaltenbreiten       = Optionales Array mit den relativen Spalten-
//                          breiten - Vorgabe ist gleiche Spaltenbreiten
//   Spaltenausrichtungen = Optionales Arry mit den Spaltenausrichtungen
//                          L  Links ausgerichtet = Voreinstellung
//                          J  Blocksatz
//                          C  zentriert
//                          R  rechtsbuendig
//****
function table_init ($SPALTEN,              // Anzahl der Tabellen-Spalten
                     $FONT,$FONTSIZE,       // Schriftart und Groesse
                     $RAHMEN = 0,           // Rahmen ja/nein
                     $TABELLE = NULL,       // Array mit den Spaltenbreiten
                     $AUSRICHTUNG = NULL)   // Array mit den Spaltenausrichtungen
{
  $this->Tabelle[CL_UVEREINPDF_TABSPALTEN] = ($SPALTEN > 0) ? $SPALTEN : 1;
  $this->Tabelle[CL_UVEREINPDF_TABSCHRIFT] = $FONT;
  $this->Tabelle[CL_UVEREINPDF_TABSCHRIFTGROESSE] = $FONTSIZE;
  $this->Tabelle[CL_UVEREINPDF_TABRAHMEN] = $RAHMEN;
  // Spaltenbreiten auswerten
  if ($TABELLE != NULL)
  {
    if (count($TABELLE) < $this->Tabelle[CL_UVEREINPDF_TABSPALTEN])
    {
      $i = count($TABELLE); while ($i < $this->Tabelle[CL_UVEREINPDF_TABSPALTEN])
      {
        $TABELLE[$i] = 1;
        $i++;
      }
    }
    $i = 0; foreach ($TABELLE as $key => $inhalt)
    {
      $i += $inhalt;
    }
    $x = 0; foreach ($TABELLE as $key => $inhalt)
    {
      $this->Tabelle[CL_UVEREINPDF_TABSPALTENBREITE][$x] = intval(170 * $inhalt / $i);
      $x++;
    }
  }
  else
  {
    $x = intval(170 / $this->Tabelle[CL_UVEREINPDF_TABSPALTEN]);
    $i = 0; while ($i < $this->Tabelle[CL_UVEREINPDF_TABSPALTEN])
    {
      $this->Tabelle[CL_UVEREINPDF_TABSPALTENBREITE][$i] = $x; $i++;
    }
  }
  // Spaltenausrichtung auswerten (gilt nicht fuer Kopfzeile)
  if ($AUSRICHTUNG != NULL)
  {
    if (count($AUSRICHTUNG) < $this->Tabelle[CL_UVEREINPDF_TABSPALTEN])
    {
      $i = count($AUSRICHTUNG); while ($i < $this->Tabelle[CL_UVEREINPDF_TABSPALTEN])
      {
        $AUSRICHTUNG[$i] = "L";
        $i++;
      }
    }
    $i = 0; foreach ($AUSRICHTUNG as $key => $inhalt)
    {
      $WERTE = array ("L","l","R","r","C","c");
      if (in_array($inhalt,$WERTE))
        $this->Tabelle[CL_UVEREINPDF_TABAUSRICHTUNG][$i] = $inhalt;
      else
        $this->Tabelle[CL_UVEREINPDF_TABAUSRICHTUNG][$i] = "L";
      $i++;
    }
  }
  else
  {
    $i = 0; while ($i < $this->Tabelle[CL_UVEREINPDF_TABSPALTEN])
    {
      $this->Tabelle[CL_UVEREINPDF_TABAUSRICHTUNG][$i] = "L"; $i++;
    }
  }
}

//
// Ausgabe einer Tabellenzeile - Klassenintern
//

function internal_tabline ($line,$bold) {
  $this->SetFont ($this->Tabelle[CL_UVEREINPDF_TABSCHRIFT],$bold,
                  $this->Tabelle[CL_UVEREINPDF_TABSCHRIFTGROESSE]);
  $baselen = intval($this->GetStringWidth ("A"))+1;
  $i = 0; while ($i < count($line)) {
    $maxlen = $this->Tabelle[CL_UVEREINPDF_TABSPALTENBREITE][$i];
    $xlen = intval($maxlen / $baselen) - 5;
    $INHALT = explode (" ",$this->uvereinpdf_caseconvert($line[$i]),$xlen);
    $iii = 0; $S[$i][$iii] = "";
    $ii = 0; while ($ii < count($INHALT)) {
      $txtlen = $this->GetStringWidth($S[$i][$iii]) +
                $this->GetStringWidth($INHALT[$ii]);
      if ($txtlen >= $maxlen) {
        $iii++; $S[$i][$iii] = "";
      }
      $S[$i][$iii] .= $INHALT[$ii] . " ";
      $ii++;
    }
    $i++;
  }
  $maxlines = 1; $i = 0;
  while ($i < $this->Tabelle[CL_UVEREINPDF_TABSPALTEN]) {
    $maxlines = ($maxlines > count($S[$i])) ? $maxlines : count($S[$i]);
    $i++;
  }
  $i = 0; while ($i < $maxlines)   {
    $ii = 0; while ($ii < $this->Tabelle[CL_UVEREINPDF_TABSPALTEN]) {
      if ($this->Tabelle[CL_UVEREINPDF_TABRAHMEN] != 0) {
        if ($i == 0) $Border = (($i + 1) <  $maxlines) ? "TLR" : 1;
        else         $Border = (($i + 1) == $maxlines) ? "BLR" : "LR";
      }
      else $Border = 0;
      if ($i < count($S[$ii])) {
        $this->Cell ($this->Tabelle[CL_UVEREINPDF_TABSPALTENBREITE][$ii],
                     intval($this->Tabelle[CL_UVEREINPDF_TABSCHRIFTGROESSE]/2),

                     $S[$ii][$i],$Border,0,
                     $this->Tabelle[CL_UVEREINPDF_TABAUSRICHTUNG][$ii],1);
      }
      else {
        $this->Cell (intval($this->Tabelle[CL_UVEREINPDF_TABSPALTENBREITE][$ii]),
                     intval($this->Tabelle[CL_UVEREINPDF_TABSCHRIFTGROESSE]/2),
                     " ",$Border,0,
                     $this->Tabelle[CL_UVEREINPDF_TABAUSRICHTUNG][$ii],1);
      }
      $this->Cell (1,
                   intval($this->Tabelle[CL_UVEREINPDF_TABSCHRIFTGROESSE]/2),
                   " ",$Border,0,'',0);
      $ii++;
    }
    $this->Cell (0,intval($this->Tabelle[CL_UVEREINPDF_TABSCHRIFTGROESSE]/2)," ",0,1,'',1);
    $i++;
  }
}

//****f* uvereinpdf.inc/table_head (Tabellenzeile)
//  FUNCTION
//   function table_head (Tabellenzeile)
//   Die Funktion erstellt die Kopfzeile der Tabelle
//   Die Spalteninhalte werden als Array uebergeben.
//
//   Beispiel:
//   $PDF->table_head (array ("1. Spalte","2. Spalte", "", "4.Spalte");
//
//****
function table_head ($TABELLE)
{
  $i = 0; while ($i < $this->Tabelle[CL_UVEREINPDF_TABSPALTEN])
  {
    $MERKER [$i] = $this->Tabelle[CL_UVEREINPDF_TABAUSRICHTUNG][$i];
    $this->Tabelle[CL_UVEREINPDF_TABAUSRICHTUNG][$i] = "C";
    $i++;
  }
  $this->internal_tabline ($TABELLE,"B");
  $i = 0; while ($i < $this->Tabelle[CL_UVEREINPDF_TABSPALTEN])
  {
    $this->Tabelle[CL_UVEREINPDF_TABAUSRICHTUNG][$i] = $MERKER[$i];
    $i++;
  }
}

//****f* uvereinpdf.inc/table_line (Tabellenzeile)
// FUNCTION
//   function table_line (Tabellenzeile)
//   Die Funktion fuegt eine Zeile in die Tabelle ein
//   Die Spalteninhalte werden als Array uebergeben.
//
//   Beispiel:
//   $PDF->table_line (array ("1. Spalte","2. Spalte", "", "4.Spalte");
//
//****
function table_line ($TABELLE)
{
  $this->TabColor = ($this->TabColor != 255) ? 255 : 240;
  $this->SetFillColor ($this->TabColor);
  $this->internal_tabline ($TABELLE,"");
}

//****f* uvereinpdf.inc/textzeile (Text, Font, Fontsize, Ausrichtung)
// FUNCTION
//   function textzeile (Text, Font, Fontsize, Ausrichtung)
//   Die Funktion fuegt Text in das PDF-Dokument ein.
//
//   Text        = Text, der als PDF eingefuegt wird
//   Font        = Optionale Schriftart -> Voreinstellung: Arial
//   Fontsize    = Optionale Schrfitgroesse -> Voreinstellung: 10
//   Ausrichtung = Optionale Ausrichtung des Textes. Moegliche Werte:
//                 L  Links ausgerichtet = Voreinstellung
//                 J  Blocksatz
//                 C  zentriert
//                 R  rechtsbuendig
//****
function textzeile ($S,$FONT = "",$FONTSIZE = 10, $AUSRICHTUNG = "L")
{
  $FONT = ($FONT == "") ? "Arial" : $FONT;
  $this->SetFont ($FONT,'',$FONTSIZE);
  $S = $this->uvereinpdf_caseconvert($S);
  $this->MultiCell (0,intval($FONTSIZE/2),$S,0,$AUSRICHTUNG,0);
}

//****f* uvereinpdf.inc/cl_uvereinpdf (Kopfzeile, Fusszeile)
// DEFINITION
//   function cl_uvereinpdf (Kopfzeile, Fusszeile)
//   Klassendefinition
//
//   Kopfzeile = Wert fuer die Kopfzeile aller Seiten
//   Fusszeile = Wert fuer die Fusszeile aller Seiten
//****
function cl_uvereinpdf ($Head, $Foot)
{
  $this->FPDF ("P","mm","A4");
  $this->SetHeader = $Head;
  $this->SetFooter = $Foot;
  $this->NewPage = false;
  $this->SetLeftMargin(20);
  $this->SetRightMargin(20);
  $this->SetTempDir = "../tmp";
  $this->AddPage();
  $this->SetFont ('Arial','',18);
  $this->PDFName = "uverein" . time() . ".pdf";
  $this->TabColor = 255;
  $this->SetFillColor (255);
}

//****f* uvereinpdf.inc/anzeige ()
// DEFINITION
//   function anzeige ()
//   PDF-Dokument ausgeben
//****
function anzeige ()
{
  $this->Close ();
  $this->Output ($this->SetTempDir."/".$this->PDFName,"F");
  echo "<SCRIPT language=\"JavaScript\">";
  echo "self.location.href=\"".$this->SetTempDir."/".$this->PDFName."\";";
  echo "</SCRIPT>";
}

}

?>
