<?php

require ("fpdf/fpdf.php");

// -------------------------------------------------------------------
// Konstanten definieren
// -------------------------------------------------------------------

// *** Art der Ansicht
define ('VIEW_PDF',  0);             // PDF-Ansicht
define ('VIEW_HTML', 1);             // HTML-Ansicht

// *** Definition der PDF-Seite 
define ('A4_BREITE', 190);           // Sichtbare Breite der PDF-Seite
define ('A4_LAENGE', 260);           // Sichtbare Laenge der PDF-Seite

// *** Definition der Array-Bestandteile fuer die Uebersetzung der 
// *** HTML-Tags in die PDF-Darstellung
define ('VIEW_TAGFONT',   'FONT');    // Welcher Font wird gewaehlt
define ('VIEW_COLOR',     'COLOR');   // Farbe der Schrift
define ('VIEW_BACKGROUND','BACK');    // Hintergrund-Farbe
define ('VIEW_TAGWIDTH', 'WIDTH');    // Schriftgroesse
define ('VIEW_TAGHIGTH', 'HIGHT');    // Zeilenhoehe
define ('VIEW_ALIGN',    'ALIGN');    // Ausrichtung

// -------------------------------------------------------------------
// Klassendefinition
// -------------------------------------------------------------------
class cl_view extends FPDF
{
  var $VIEW_ART;            // Art der Anzeige (PDF oder HTML)
  var $ANZEIGE;             // Seitentext fuer HTML-Anzeige
  var $PDF_Tag;             // Uebersetzung von HTML-Tags

// ------------------------------------------------------------------
// PDF-Defnition fuer HTML-TAGS
// ------------------------------------------------------------------
function tag_definition ($name,       // Name, z.B. H1 fuer <H1> 
                         $font,       // Welcher Font wird gewaehlt
                         $color,      // Farbe der Schrift
                         $background, // Hintergrund-Farbe
                         $groesse,    // Schriftgroesse
                         $hoehe,      // Zeilenhoehe
                         $aus         // Ausrichtung
                        )
{
  $name = strtoupper ($name);
  $this->PDF_Tag["$name"][VIEW_TAGFONT]    = $font;
  $this->PDF_Tag["$name"][VIEW_COLOR]      = $color;
  $this->PDF_Tag["$name"][VIEW_BACKGROUND] = $background;
  $this->PDF_Tag["$name"][VIEW_TAGWIDTH]   = $groesse;
  $this->PDF_Tag["$name"][VIEW_TAGHIGTH]   = $hoehe;
  $this->PDF_Tag["$name"][VIEW_ALIGN]      = $aus;
}                       

// -------------------------------------------------------------------
// HTML-Tags fuer die PDF-Darstellung definieren - diese Funktion
// muss ggf. in einer abgeleiteten Klasse ueberschrieben werden um 
// eigene Definitionen zu integrieren
// -------------------------------------------------------------------
function define_tag ()
{
  $this->tag_definition ("BASIS" ,"Arial",0,255,10,5,'L');    // Grundwert
  $this->tag_definition ("HEADER","Arial",0,220,20,10,'C');   // Seiten-Ueberschrift
  $this->tag_definition ("FOOTER","Arial",0,250,8,5,'L');     // Fusszeile
  $this->tag_definition ("H1","Arial",0,255,20,10,'C');       // <H1>
  $this->tag_definition ("H2","Arial",0,255,15,8,'C');        // <H2>
  $this->tag_definition ("H3","Arial",0,255,10,5,'C');        // <H3>
  $this->tag_definition ("BR","Arial",0,255,10,5,'C');        // <BR> Zeilenumbruch
}

// ------------------------------------------------------------------
// PDF-Textausgabe
// ------------------------------------------------------------------
function pdf_line ($s,$TAG,$FULL = 0)
{
  $TAG = strtoupper($TAG);
  $this->SetFont ($this->PDF_Tag["$TAG"][VIEW_TAGFONT],
                  '',
                  $this->PDF_Tag["$TAG"][VIEW_TAGWIDTH]);
  $this->SetTextColor($this->PDF_Tag["$TAG"][VIEW_COLOR]);
  $this->SetFillColor($this->PDF_Tag["$TAG"][VIEW_BACKGROUND]);
  $Breite = ($FULL == 0) ? $this->GetStringWidth($s) : 0;
  $this->Cell($Breite,
              $this->PDF_Tag["$TAG"][VIEW_TAGHIGTH],
              $s,
              0,
              0,
              $this->PDF_Tag["$TAG"][VIEW_ALIGN],
              ($this->PDF_Tag["$TAG"][VIEW_BACKGROUND] == 255) ? 0 : 1);
  // Zeilenumbruch muss immer gleich aktueller Zeichenhoehe sein
  if ($TAG == "BR")
    $this->Cell(0,$this->PDF_Tag["$TAG"][VIEW_TAGHIGTH],"",0,1,'L',
                ($this->PDF_Tag["$TAG"][VIEW_BACKGROUND] == 255) ? 0 : 1);
}

// -------------------------------------------------------------------
// Klasse initialisieren
// -------------------------------------------------------------------

function cl_view ($art,              // Art der Anzeige
                  $titel = NULL,     // Titel der HTML-Seite 
                                     // bzw. Header der PDF-Seite
	               $body = NULL,      // Hintergrundfarbe oder CSS-Class
	                                  // bzw. Footer der PDF-Seite
	               $css = NULL,       // Stylesheet
	               $background = NULL // Hintergrund-Bild
	              )
{
  switch ($art)
  {
    case VIEW_PDF : 
      $this->FPDF("P","mm","A4");
      $this->SetHeader = ($titel == NULL) ? "" : $titel;
	   $this->SetFooter = ($body == NULL)  ? "" : $body;
	   $this->SetLeftMargin  (20);
	   $this->SetRightMargin (20);
	   $this->define_tag ();
	   $this->FontName = ($css == NULL) ? 'Arial' : $css;
	   $this->AddPage();
	   $this->VIEW_ART = VIEW_PDF;
      break;
    default :
      $this->VIEW_ART = VIEW_HTML;
	   $this->ANZEIGE  = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" ".
	                     "\"http://www.w3.org/TR/html4/loose.dtd\">";
      $this->ANZEIGE .= "<HTML><HEAD><META http-equiv=\"content-type\" ".
	                     "content=\"text/html; charset=utf-8\">";
	   $this->ANZEIGE .= "<TITLE>";
	   $this->ANZEIGE .= ($titel == NULL) ? basename($_SERVER["PHP_SELF"]) : $titel;
	   $this->ANZEIGE .= "</TITLE>";
	   $this->ANZEIGE .= ($css == NULL) 
	                   ? "" 
	                   : "<LINK rel=\"stylesheet\" type=\"text/css\" href=\"$css\">";
	   $this->ANZEIGE .= "</HEAD>";
      $BODY  = ($body == NULL) ? "" 
             : ($css == NULL)  ? "bgcolor=\"$body\"" : "class=\"$body\"";
      $BODY .= " ";
      $BODY .= ($background == NULL) ? "" : "background=\"$background\"";
      $this->ANZEIGE .= "<BODY $BODY>";
      break;
  }
}

// -------------------------------------------------------------------
// Seite abschliessen
// -------------------------------------------------------------------
function ende ()
{
  if ($this->VIEW_ART == VIEW_PDF)
  {
    $this->Close();
    $this->Output("","I");
  }
  else
  {
    $this->ANZEIGE .= "</BODY></HTML>";
    echo $this->ANZEIGE;
  }
}

// *******************************************************************
// Definition fuer
// 
// P D F - D a r s t e l l u n g
//
// *******************************************************************

// -------------------------------------------------------------------
// Kopfzeile der Blaetter - ueberschreibt leere Funktion aus FPDF
// -------------------------------------------------------------------
function Header ()
{
  $this->SetY(10);
  $this->pdf_line ($this->SetHeader,"HEADER",1);
  $this->SetY($this->GetY() + 15);
}

// -------------------------------------------------------------------
// Fusszeile der Blaetter - ueberschreibt leere Funktion aus FPDF
// -------------------------------------------------------------------
function Footer ()
{
  $this->SetLineWidth (0.1);
  $this->AliasNbPages ("{MS}");
  $this->SetY (-15);
  $this->pdf_line ($this->SetFooter,"FOOTER",1);
  $this->Cell (0,$this->PDF_Tag["FOOTER"][VIEW_TAGHIGTH],$this->PageNo() . "/{MS}",'',1,'R');
}

function pdf_anzeige ($s,$art = "BASIS")
{
// 
// Auswertung der HTML-Tags und ersetzen durch definierte Angaben
//
  $this->pdf_line ($s,strtoupper($art));
}

// *******************************************************************
// Definition fuer
// 
// H T M L - D a r s t e l l u n g
//
// *******************************************************************
function html_anzeige ($s)
{
  $this->ANZEIGE .= $s;
}

// *******************************************************************
// 
// Allgemeine Einstellungen
//
// *******************************************************************

function auswertung ($s,$art)
{
  if ($this->VIEW_ART == VIEW_PDF)
  {
    $this->pdf_anzeige ($s,$art);
  }
  else
  {
    $this->html_anzeige ("<$art>$s</$art>");
  }
}

function L_ine ($s ,             // auszugebender Text
                $art = "BASIS",  // HTML-Tag
                $nl = false      // Zeilenumbruch nach Textausgabe
               )
{
  $art = strtoupper($art);
  $this->auswertung ($s,$art);
  if ($nl == true) 
  { 
    $this->auswertung("","BR"); 
  }
}              

}  // Ende der Klasse

?>