<?php
//****h* Finanzbuchhaltung/print.belege.php
// NAME
//   print.belege.php
// BESCHREIBUNG
//   Erstellt eine Aufstellung der Buchungsbelege als PDF-Dokument
//
//   Uebergabe-Parameter werden ueber Super-Globals uebermittelt
//
//   ART = Art der Aufstellung
//     * BELEG     alle Buchungsbelege = Voreinstellung
//     * KONTO     nur Buchungsbelege zu einem bestimmten Konto
//     * KST       nur Buchungsbelege zu einer bestimmten Kostenstelle
//     * NR        nur eine Beleg-Nummer
//     * BU_KLASSE Buchungsbelege zur Kontenklasse
//        
//   WERT = Nummer des Kontos, Kostenstelle, Klasse oder Beleg-Nr.  
//***
include_once "base.inc";
include_once "klassen/uvereinpdf.inc";

$PRINT_ART = $FORM->returnglobal("ART");

switch ($PRINT_ART)
{
  case 'KONTO' :
    $PRINT_WERT = $FORM->returnglobal("WERT",0);
    $ART = $UVEREIN_DB->get_kontenname ($PRINT_WERT)." (".$AKT_YEAR.")";
    $SUCHE = "f_konto='$PRINT_WERT' OR b_konto='$PRINT_WERT'";
    $ORDER = "b_datum,b_nr";
    $ERG   = " [".i4l("bu_konto")."]"; 
    break;
    
  case 'KST' :
    $PRINT_WERT = $FORM->returnglobal("WERT",0);
    $ART = $UVEREIN_DB->sql_1_value("bu_kst",
                                    "kst_name",
                                    "kst='$PRINT_WERT' AND verein='$VEREIN_NAME'").
           " (".$AKT_YEAR.")";
    $SUCHE = "b_kst='$PRINT_WERT'";
    $ORDER = "b_datum,b_nr";
    $ERG   = " [".i4l("bu_kst")."]";
    break;

  case 'NR' :
    $PRINT_WERT = $FORM->returnglobal("WERT",0);
    $ART = i4l("bu_belege_nr"). " $PRINT_WERT";
    $SUCHE = "b_nr='$PRINT_WERT'";
    $ORDER = "b_datum,b_text";
    $ERG   = "";
    break;
    
  case 'BU_KLASSE':
    $PRINT_WERT = $FORM->returnglobal("WERT",0);
    $ART = $UVEREIN_DB->sql_1_value("bu_klassen","kl_name","kl_nr='$PRINT_WERT' AND verein='$VEREIN_NAME'")." ($AKT_YEAR)";
    $SUCHE = "f_konto IN (SELECT kto_nr FROM bu_konten WHERE kto_klasse='$PRINT_WERT')". 
             " OR b_konto IN (SELECT kto_nr FROM bu_konten WHERE kto_klasse='$PRINT_WERT')";
    $ORDER = "b_datum,b_nr,b_betrag";
    $ERG   = " [".i4l("bu_k_bereich")."]";
    break;
  default:
    $ART = i4l("bu_belege")." ".$AKT_YEAR;
    $SUCHE = "";
    $ORDER = "b_nr,b_datum";
    $ERG   = "";
    break;
}  
$PDF = new cl_uvereinpdf ($ART, $UVEREIN_DB->get_vereinsname().$ERG);

$SEITENLAENGE = 250;
// --------------------------------------------------------
// Zahlendarstellung mit 2 Nachkommastellen
// --------------------------------------------------------
function zahl ($x)
{
  global $FORM;
  return ($FORM->numeingabe2anzeige($x,2));
}

// ---------------------------------------------------------
// Zwischensumme beim Seitenwechsel
// ---------------------------------------------------------
function neueseite ($art = "AUTO")
{
  global $ueberschrift, $SUMME, $PDF, $FORM, $SEITENLAENGE;
  if ($PDF->GetY() > $SEITENLAENGE)
  {
    $PDF->table_line("");
    $inhalt[0] = "";
    $inhalt[1] = "";
    $inhalt[2] = "";
    $inhalt[3] = zahl($SUMME["SOLL"]);
    $inhalt[4] = zahl($SUMME["HABEN"]);
    $inhalt[5] = zahl($SUMME["STEUER"]);
    $inhalt[6] = "";
    $PDF->table_line($inhalt);
    if ($art == "AUTO")
    {
      $PDF->AddPage();
      $PDF->table_head ($ueberschrift);
      $PDF->table_line($inhalt);
      $PDF->table_line("");
    }
  }
}

// --------------------------------------------------------
// PDF-Tabelle erstellen
// --------------------------------------------------------
$PDF->table_init (7,"Times",8,1,array(2,2,3,2,2,2,6),array("C","L","L","R","R","R","L"));
$ueberschrift[0] = i4l("data_nr");
$ueberschrift[1] = i4l("data_datum");
$ueberschrift[2] = i4l("data_konto") . " / " . i4l("data_finanzkonto");
$ueberschrift[3] = i4l("data_soll");
$ueberschrift[4] = i4l("data_haben");
$ueberschrift[5] = i4l("data_uststeuer");
$ueberschrift[6] = i4l("data_buchungstext");
$PDF->table_head ($ueberschrift);

// --------------------------------------------------------
// Besondere Informationen ermitteln
// --------------------------------------------------------
// Finanzkonten befinden sich in ?
$FART = $UVEREIN_DB->sql_1_value("virtual_konto","konto","art='FINANZKONTO' AND verein='$VEREIN_NAME'");
// Welches Konto enthaelt die verrechnete Vorsteuer ?
$VART = $UVEREIN_DB->sql_1_value("virtual_konto","fkonto","art='VORSTEUER' AND verein='$VEREIN_NAME'");

// --------------------------------------------------------
// Buchungen abfragen
// --------------------------------------------------------
$UVEREIN_DB->get_beleg ($SUCHE,$ORDER);
// ---------------------------------------------------------
// Summen auf 0 setzen
// ---------------------------------------------------------
$SUMME["SOLL"]   = 0;
$SUMME["HABEN"]  = 0;
$SUMME["STEUER"] = 0;
// Marker fuer Finanzkonten
$FinanzKonto = ($UVEREIN_DB->get_kontenklasse($konto) == $UVEREIN_DB->get_vfinanz())
             ? 1 : -1;
// ---------------------------------------------------------
// Belege in Tabelle eintragen
// ---------------------------------------------------------
$i = 0; while ($i < $UVEREIN_DB->sql_lines())
{
  // Datensatz holen
  $data = $UVEREIN_DB->sql_line($i); $i++;
  // Wenn nur ein Finanzkonto dargestellt wird Soll/Haben korrigieren
  if (($PRINT_ART == "KONTO") and ($data->b_konto == $PRINT_WERT))
  {
    $SOLL  = (($data->b_betrag * $FinanzKonto) < 0) 
           ? -($data->b_betrag * $FinanzKonto) : "";
    $HABEN = (($data->b_betrag * $FinanzKonto) < 0) 
           ? "" : ($data->b_betrag * $FinanzKonto);
  }
  else // Buchung in Soll (-) oder Haben (+) eintragen
  {
    $SOLL  = ($data->b_betrag < 0) ? -$data->b_betrag : "";
    $HABEN = ($data->b_betrag < 0) ? "" : $data->b_betrag;
  }
  // Handelt es sich um eine Umbuchung?
  $KART =  ($UVEREIN_DB->get_kontenklasse ($data->b_konto) == $FART) ? 1 : 0;
  $KART += ($UVEREIN_DB->get_kontenklasse ($data->f_konto) == $FART) ? 1 : 0;
  // Soll und Haben gleich, wenn nur Umbuchung
  if (($KART <> 1) and ($PRINT_ART != "KONTO"))
  {
    $SOLL = $data->b_betrag * (($data->b_betrag < 0) ? -1 : 1);
    $HABEN = $SOLL;
  }
  // Buchungs-Nr.
  $inhalt[0] = $data->b_nr;
  // Buchungs-Datum
  $inhalt[1] = $data->b_datum;
  // Buchungskonto und Finanzkonto eintragen
  $inhalt[2] = $UVEREIN_DB->get_kontenname($data->b_konto).
                " / " .
               $UVEREIN_DB->get_kontenname($data->f_konto);
  // Soll
  $inhalt[3] = zahl($SOLL);
  // Haben
  $inhalt[4] = zahl($HABEN);
  // Vorsteuer
  $inhalt[5] = zahl($data->b_steuer);
  // Buchungstext
  $inhalt[6] = $data->b_text;
  // Daten in Tabellenzeile eintragen
  $PDF->table_line($inhalt);
  // Summen bilden
  $SUMME["SOLL"]   += $SOLL;
  $SUMME["HABEN"]  += $HABEN;
  $SUMME["STEUER"] += $data->b_steuer;
  // Neue Seite erforderlich ? Wenn ja, Uebertrag bilden
  neueseite();
}

// --------------------------------------------------------
// Beitragsbuchungen abfragen
// --------------------------------------------------------
$UVEREIN_DB->sql_befehl  ("SELECT f_konto,sum(haben) AS haben FROM beitrag".
                          " WHERE v_name='$VEREIN_NAME' AND jahr='$AKT_YEAR'".
                          " GROUP BY f_konto");
// ---------------------------------------------------------
// Beitrag in Tabelle eintragen
// ---------------------------------------------------------
// Buchungs-Nr.
$inhalt[0] = "*";
// Buchungs-Datum
$inhalt[1] = "";
// Vorsteuer
$inhalt[5] = "";
// Buchungstext
$inhalt[6] = i4l("beitrag");
$TEST_KONTO = $UVEREIN_DB->get_vbeitrag();
$TEST_KST   = $UVEREIN_DB->get_vbeitrag("KST");
$i = 0; while ($i < $UVEREIN_DB->sql_lines())
{
  // Datensatz holen
  $data = $UVEREIN_DB->sql_line($i); $i++;
  switch ($PRINT_ART)
  {
    case 'KONTO' : $OK = ($TEST_KONTO == $PRINT_WERT)   ? 1 : 0;
                   $OK = ($PRINT_WERT == $data->f_konto) ? 1 : $OK;
                   break;
    case 'KST'   : $OK = ($TEST_KST == $PRINT_WERT)   ? 1 : 0;
                   break;
    case 'NR'    : $OK = 0; break;
    default      : $OK = 1; break;
  }
  if ($OK == 1)
  if ($data->haben <> 0)
  {
    // Buchung in Soll (-) oder Haben (+) eintragen
    $SOLL  = ($data->haben < 0) ? -$data->haben : "";
    $HABEN = ($data->haben < 0) ? "" : $data->haben;
    // Buchungskonto und Finanzkonto eintragen
    $inhalt[2] = $UVEREIN_DB->get_kontenname($data->f_konto);
    // Soll
    $inhalt[3] = zahl($SOLL);
    // Haben
    $inhalt[4] = zahl($HABEN);
    // Daten in Tabellenzeile eintragen
    $PDF->table_line($inhalt);
    // Summen bilden
    $SUMME["SOLL"]   += $SOLL;
    $SUMME["HABEN"]  += $HABEN;
    // Neue Seite erforderlich ? Wenn ja, Uebertrag bilden
    neueseite();
  }
}

// --------------------------------------------------------
// Schluss-Summe bilden
// --------------------------------------------------------
$SEITENLAENGE -= 50;
neueseite ("ENDE");
$PDF->table_line("");
$inhalt[0] = "";
$inhalt[1] = "";
$inhalt[2] = "";
$inhalt[3] = zahl($SUMME["SOLL"]);
$inhalt[4] = zahl($SUMME["HABEN"]);
$inhalt[5] = zahl($SUMME["STEUER"]);
$inhalt[6] = "";
$PDF->table_line($inhalt);

$inhalt[0] = "*";
$inhalt[1] = "*";
$inhalt[2] = i4l("gesamt-summe");
$inhalt[3] = ($SUMME["SOLL"]  > $SUMME["HABEN"]) ? zahl($SUMME["SOLL"] - $SUMME["HABEN"]) : "";
$inhalt[4] = ($SUMME["HABEN"] > $SUMME["SOLL"])  ? zahl($SUMME["HABEN"] - $SUMME["SOLL"]) : "";
$inhalt[5] = zahl($SUMME["STEUER"]);
$inhalt[6] = "";
$PDF->table_line($inhalt);

// --------------------------------------------------------
// Gewinn- und Verlustrechung
// --------------------------------------------------------
$inhalt[0] = "";
$inhalt[1] = "";
$inhalt[2] = "";
$GESAMT_SUMME = $SUMME["HABEN"] - $SUMME["SOLL"] + $SUMME["STEUER"]; 
$inhalt[3] = ($GESAMT_SUMME < 0) ? zahl(-$GESAMT_SUMME) : "";
$inhalt[4] = ($GESAMT_SUMME < 0) ? "" : zahl($GESAMT_SUMME);
$inhalt[5] = "";
$inhalt[6] = i4l("bu_bilanz");
$PDF->table_line($inhalt);

// --------------------------------------------------------
// Vorsteuer beruecksichtigen
// --------------------------------------------------------
$TEST_KONTO = $UVEREIN_DB->get_vsteuer();
$SOLL = $UVEREIN_DB->sql_1_value("bu_belege","sum(b_betrag)",
         "b_konto='$VART' AND b_jahr='$AKT_YEAR' AND b_verein='$VEREIN_NAME'");
switch ($PRINT_ART)
{
  case 'KONTO' : $OK = ($TEST_KONTO == $PRINT_WERT) ? 1 : 0; break;
  case 'KST'   : $OK = 0; break;
  case 'NR'    : $OK = 0; break;
  default      : $OK = 1; break;
}
if ($OK == 1)
if ($SOLL <> 0)
{
  $inhalt[0] = "";
  $inhalt[1] = "";
  $inhalt[2] = "";
  $inhalt[3] = "";
  $inhalt[4] = "";
  $inhalt[5] = zahl($SOLL);
  $inhalt[6] = i4l("abgerechnet");
  $PDF->table_line($inhalt);
  $SOLL = ($SUMME["STEUER"] - $SOLL);
  $inhalt[3] = ($SOLL < 0) ? zahl($SOLL * -1) : "";
  $inhalt[4] = ($SOLL > 0) ? zahl($SOLL)      : "";
  $inhalt[5] = "";
  $inhalt[6] = i4l("vorsteuer");
  $PDF->table_line($inhalt);
}

// --------------------------------------------------------
// PDF-Dokument auf Bildschirm ausgeben
// --------------------------------------------------------
$PDF->anzeige();

?>