--****h* Installation/muster.sql
-- NAME
--   sql/muster.sql
-- AUTOR
--   Uwe Schied
-- COPYRIGHT
--   GPL
-- HISTORIE
--   14.04.2009 komplett ueberarbeitet
--   07.06.2009 Jahresangabe korrigiert - nur aktuelles Jahr eintragen
-- BUGS
--   Keine bekannt
--****

--****I* muster.sql/muster
-- INFO
--   Diese Tabelle existiert fuer jeden Verein und enthaelt die Informationen
--   ueber die dem Verein zugeordneten Mitglieder
-- SOURCE
CREATE TABLE muster (
  nr          INT8 DEFAULT 1 NOT NULL UNIQUE REFERENCES personen(nr),
  eintritt    DATE NOT NULL,
  ende        DATE,
  kommentar   TEXT,
  zahlungsart SMALLINT DEFAULT 1 NOT NULL REFERENCES key_zahlungsarten (nr),
  aktiv       BOOLEAN DEFAULT true
);
-- BESCHREIBUNG
--   nr          Mitglieds-Nr. (identisch mit Nr. in der Tabelle "personen")
--   eintritt    Eintrittsdatum
--   ende        Vereinsaustritt
--   kommentar   Bemerkungen zum Mitglied
--   zahlungsart Zahlungsart fuer den Mitgliedsbeitrag
--   aktiv       Voreinstellung ist true - ausgeschiedene Mitglieder = false
--               Die Spalte wird durch den Cronjob "bash/uverein.hour_cron"
--               stuendlich aktualisiert.
--****
ALTER TABLE muster OWNER TO "www-data";

--****I* muster.sql/muster_einzug
-- INFO
--   Die Tabelle verwaltet die Einzugsermaechtigungen und existiert fuer jeden
--   Verein
-- SOURCE
CREATE TABLE muster_einzug (
  nr    INT8 DEFAULT 1 NOT NULL UNIQUE REFERENCES muster (nr),
  blz   NUMERIC (8,0) NOT NULL REFERENCES key_banken (blz),
  konto NUMERIC (10,0) NOT NULL
);
-- BESCHREIBUNG
--   nr    Mitglieds-Nr. (siehe muster)
--   blz   Bankleitzahl
--   konto Konto-Nr.
--****
ALTER TABLE muster_einzug OWNER TO "www-data";
-- -------------------------------------
-- B E G I N   O F   T A B L E   vereine
-- -------------------------------------
INSERT INTO vereine (name,kurzname,strasse,ort,blz,bank,kontonr,email,version) VALUES ('Muster-Verein','muster','Musterstr. 10','99999 Musterhausen','54651240','KSK','0','uverein@gmx.de','0.2.1R4');

-- --------------------------------------
-- B E G I N   O F   T A B L E   personen
-- --------------------------------------
INSERT INTO personen (anrede,titel,name,vorname,geboren,strasse,hausnr,land,plz,ort,telefon,email) VALUES ('1','','Muster','Hans','1800-01-01','Musterstrasse','1','Deutschland','99999','Musterhausen','','');

-- ------------------------------------
-- B E G I N   O F   T A B L E   muster
-- ------------------------------------
INSERT INTO muster (nr,eintritt,kommentar,zahlungsart) SELECT nr, '2004-01-01','Muster-Mitglied','2'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';

-- -------------------------------------------
-- B E G I N   O F   T A B L E   muster_einzug
-- -------------------------------------------
INSERT INTO muster_einzug SELECT nr, '0', '0'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';

-- -------------------------------------
-- B E G I N   O F   T A B L E   beitrag
-- -------------------------------------
INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text) SELECT 'muster',nr,EXTRACT (YEAR FROM CURRENT_DATE),'91000','2003-01-01','100.00','0.00','Soll'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';
INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text) SELECT 'muster',nr,EXTRACT (YEAR FROM CURRENT_DATE),'91000','2003-01-01','0.00','100.00','Haben'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';
INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text) SELECT 'muster',nr,EXTRACT (YEAR FROM CURRENT_DATE),'91000','2004-01-01','20.00','0.00','Jahresbeitrag'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';
INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text) SELECT 'muster',nr,EXTRACT (YEAR FROM CURRENT_DATE),'91000','2005-01-01','20.00','0.00','Soll'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';
INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text) SELECT 'muster',nr,EXTRACT (YEAR FROM CURRENT_DATE),'0','2005-03-13','0.00','0.00','Mahnkosten lt. Satzung'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';
INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text) SELECT 'muster',nr,EXTRACT (YEAR FROM CURRENT_DATE),'0','2005-03-13','0.00','0.00','Mahnkosten lt. Satzung'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';
INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text) SELECT 'muster',nr,EXTRACT (YEAR FROM CURRENT_DATE),'0','2005-03-13','0.00','0.00','Mahnkosten lt. Satzung'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';
INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text) SELECT 'muster',nr,EXTRACT (YEAR FROM CURRENT_DATE),'0','2005-03-13','0.00','0.00','Mahnkosten lt. Satzung'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';
INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text) SELECT 'muster',nr,EXTRACT (YEAR FROM CURRENT_DATE),'0','2005-03-13','0.00','0.00','Mahnkosten lt. Satzung'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';
INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text) SELECT 'muster',nr,EXTRACT (YEAR FROM CURRENT_DATE),'0','2005-03-13','0.00','0.00','Mahnkosten lt. Satzung'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';
INSERT INTO beitrag (v_name,m_nr,jahr,f_konto,datum,soll,haben,bu_text) SELECT 'muster',nr,EXTRACT (YEAR FROM CURRENT_DATE),'0','2005-03-13','0.00','0.00','Mahnkosten lt. Satzung'  FROM personen WHERE name='Muster' AND vorname='Hans' AND anrede='1' AND geboren='1800-01-01' AND plz='99999';

-- ------------------------------------------
-- B E G I N   O F   T A B L E   beitrags_art
-- ------------------------------------------
INSERT INTO beitrags_art (verein,art,jahresbeitrag) VALUES ('muster','Mitgliedsbeitrag','20.00');
INSERT INTO beitrags_art (verein,art,jahresbeitrag) VALUES ('muster','Ehrenmitglied','0.00');

-- ----------------------------------------
-- B E G I N   O F   T A B L E   bu_klassen
-- ----------------------------------------
INSERT INTO bu_klassen (verein,kl_nr,kl_name) VALUES ('muster','0','Ideeler Bereich');
INSERT INTO bu_klassen (verein,kl_nr,kl_name) VALUES ('muster','1','Zweckbetrieb');
INSERT INTO bu_klassen (verein,kl_nr,kl_name) VALUES ('muster','2','Wirtschaftsbetrieb');
INSERT INTO bu_klassen (verein,kl_nr,kl_name) VALUES ('muster','3','Finanzkonten');
INSERT INTO bu_klassen (verein,kl_nr,kl_name) VALUES ('muster','4','Berechnung des Vereinsvermoegens');

-- ---------------------------------------
-- B E G I N   O F   T A B L E   bu_konten
-- ---------------------------------------
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','0','Uebertrag','4','0','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','1','Umbuchungen','4','99999','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','10000','Beitraege','0','10000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','11000','Spenden','0','11000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','11002','Spende - Gemeindewerke Weidenthal','0','11000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','12000','Vermoegensverwaltung','0','12000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','14000','Sonstige Einnahmen','0','14000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','15200','Totenehrung','0','15200','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','15300','Verwaltungskosten','0','15300','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','15400','Miete einschl. Nebenkosten','0','15400','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','15500','Ehrungen','0','15500','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','15600','Adventsfeier','0','15600','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','15700','Vereins- und Mitgliederwerbung','0','15700','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','17000','Vereinsjubilaeum','0','17000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','18000','Spenden an gemeinnuetzige Einrichtungen','0','18000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','19000','Sonstige Ausgaben','0','19000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','20001','Eintrittsgelder','1','20001','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','24999','Sonstige Einnahmen','1','24999','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','25001','Miete einschl. Nebenkosten','1','25001','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','25002','Musikerhonorare, Beschallung u.ä.','1','25002','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','25003','Dekoration, Kostüme usw.','1','25003','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','25004','GEMA-Gebühren','1','25004','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','28001','Vorbereitung auf Auftritte','1','28001','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','28003','Gastgeschenke','1','28003','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','28004','Werbung einsch. Prospekte und Plakate','1','28004','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','29000','Steuern und Abgaben','1','29000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','29999','Sonstiges','1','29999','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','30001','Veranstaltungsumsatz','2','30001','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','30002','Werbeeinnahmen','2','30002','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','30003','Eintrittsgelder','2','30003','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','34999','Sonstige Einnahmen','2','34999','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','35001','Miete einschl. Nebenkosten','2','35001','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','35002','Musikerhonorare, Beschallung u.ae.','2','35002','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','35003','Dekoration','2','35003','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','35004','GEMA-Gebuehren','2','35004','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','36000','Waren und Verkaufsmaterial','2','36000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','36001','Arbeitsgeraete und Arbeitsmaterial','2','36001','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','37000','Werbung einschl. Propekten und Plakaten','2','37000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','39000','Abschreibungen','2','39000','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','39001','Steuern und Abgaben','2','39001','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','39999','Sonstiges','2','39999','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','90000','Bargeld','3','90000','17.78',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','91000','1. Girokonto','3','91000','3464.14',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','91001','2. Girokonto','3','91001','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','92000','Sparbuch','3','92000','65.68',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','92001','Geldmarktkonto','3','92001','29217.40',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','93000','Anlagevermoegen','3','93000','1.53',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','98000','Vorsteuer','3','98000','130.88',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','99000','Offene Ueberweisungen','3','99000','-9.90',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','99001','Offene Rechnungen','3','99001','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','99997','Rechnungsabgrenzung / Rueckstellungen','3','99997','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','99998','Sonstige Forderungen und Verbindlichkeiten','3','99998','0.00',EXTRACT (YEAR FROM CURRENT_DATE));
INSERT INTO bu_konten (verein,kto_nr,kto_name,kto_klasse,kto_ziel,Kto_stand,jahr) VALUES ('muster','99999','Schwebekonto','3','99999','0.00',EXTRACT (YEAR FROM CURRENT_DATE));

-- ------------------------------------
-- B E G I N   O F   T A B L E   bu_kst
-- ------------------------------------
INSERT INTO bu_kst (verein,kst,kst_name)VALUES ('muster','1','Allgemein');
INSERT INTO bu_kst (verein,kst,kst_name)VALUES ('muster','11','Hochzeit, goldene Hochzeit u.ä.');
INSERT INTO bu_kst (verein,kst,kst_name)VALUES ('muster','12','Geburtstag(e)');
INSERT INTO bu_kst (verein,kst,kst_name)VALUES ('muster','101','Fasnacht');
INSERT INTO bu_kst (verein,kst,kst_name)VALUES ('muster','102','Kerwe');
INSERT INTO bu_kst (verein,kst,kst_name)VALUES ('muster','103','Schlachtfest');
INSERT INTO bu_kst (verein,kst,kst_name)VALUES ('muster','104','Chorfestival');
INSERT INTO bu_kst (verein,kst,kst_name)VALUES ('muster','200','Sonderveranstaltungen');
INSERT INTO bu_kst (verein,kst,kst_name)VALUES ('muster','99999','Uebertrag');

-- ---------------------------------------
-- B E G I N   O F   T A B L E   bu_belege
-- ---------------------------------------
INSERT INTO bu_belege (b_verein,b_nr,b_jahr,b_datum,b_konto,f_konto,b_betrag,b_steuer,b_text,b_kst) VALUES ('muster', 1, EXTRACT (YEAR FROM CURRENT_DATE), '2003-01-01', 0, 90000, 0.00, 0.00, '', 1);
INSERT INTO bu_belege (b_verein,b_nr,b_jahr,b_datum,b_konto,f_konto,b_betrag,b_steuer,b_text,b_kst) VALUES ('muster', 1, EXTRACT (YEAR FROM CURRENT_DATE), '2004-01-01', 0, 91000, 100.00, 0.00, '&Uuml;bertrag', 0);
INSERT INTO bu_belege (b_verein,b_nr,b_jahr,b_datum,b_konto,f_konto,b_betrag,b_steuer,b_text,b_kst) VALUES ('muster', 1, EXTRACT (YEAR FROM CURRENT_DATE), '2005-01-01', 0, 91000, 100.00, 0.00, '&Uuml;bertrag', 0);
INSERT INTO bu_belege (b_verein,b_nr,b_jahr,b_datum,b_konto,f_konto,b_betrag,b_steuer,b_text,b_kst) VALUES ('muster', 1, EXTRACT (YEAR FROM CURRENT_DATE), '2006-01-01', 0, 91000, 100.00, 0.00, '&Uuml;bertrag', 0);
INSERT INTO bu_belege (b_verein,b_nr,b_jahr,b_datum,b_konto,f_konto,b_betrag,b_steuer,b_text,b_kst) VALUES ('muster', 1, EXTRACT (YEAR FROM CURRENT_DATE), '2007-01-01', 0, 91000, 100.00, 0.00, '&Uuml;bertrag', 0);

-- -------------------------------------------
-- B E G I N   O F   T A B L E   virtual_konto
-- -------------------------------------------
INSERT INTO virtual_konto (verein,art,konto,fkonto,kst)VALUES ('muster','BEITRAG','10000','1','1');
INSERT INTO virtual_konto (verein,art,konto,fkonto,kst)VALUES ('muster','BEITRAG_1','1','0','0');
INSERT INTO virtual_konto (verein,art,konto,fkonto,kst)VALUES ('muster','BEITRAG_2','1','0','0');
INSERT INTO virtual_konto (verein,art,konto,fkonto,kst)VALUES ('muster','BEITRAG_3','1','0','0');
INSERT INTO virtual_konto (verein,art,konto,fkonto,kst)VALUES ('muster','BEITRAG_LEV','1','0','0');
INSERT INTO virtual_konto (verein,art,konto,fkonto,kst)VALUES ('muster','FINANZKONTO','3','0','0');
INSERT INTO virtual_konto (verein,art,konto,fkonto,kst)VALUES ('muster','SCHWEBEKONTO','99999','0','0');
INSERT INTO virtual_konto (verein,art,konto,fkonto,kst)VALUES ('muster','UEBERTRAG','4','0','0');
INSERT INTO virtual_konto (verein,art,konto,fkonto,kst)VALUES ('muster','VORSTEUER','98000','98000','1');

-- ------------------------------------
-- B E G I N   O F   T A B L E   briefe
-- ------------------------------------
INSERT INTO briefe (verein,nr,info,inhalt)VALUES ('muster','1','1. Erinnerung','sicher haben Sie vergessen den Beitrag zu �berweisen. Ihr Beitragskonto sieht derzeit wie folgt aus:<BR><BR>%%BEITRAG%%<BR><BR>Bitte ueberweisen Sie den faelligen Beitrag auf unser o.g. Konto.<BR><BR>Mit freundlichen Gruessen');

-- ------------------------------------
-- B E G I N   O F   T A B L E   bilanz
-- ------------------------------------
INSERT INTO bilanz VALUES ('muster', EXTRACT (YEAR FROM CURRENT_DATE), 10000, 'EUR', 'Musterkommentar', 'Musterpr&uuml;f-Text', '2003-12-31');
