--****h* Installation/update_0.2.1-17.sql
-- NAME
--   sql/update_0.2.1-17.sql
-- AUTOR
--   Uwe Schied
-- COPYRIGHT
--   GPL
-- INFO
--   Version 0.2.1-17
--   Umsatzsteuerberechnung einfuegen
--****

DROP TABLE tax;            -- Alte Tabelle entfernen (wurde bisher nicht benutzt)
DROP TABLE tax_konten;     -- Loeschen falls aus Test vorhanden
DROP TABLE tax_base;       -- Loeschen falls aus Test vorhanden

-- Tabelle fuer die Basisdaten anlegen
CREATE TABLE tax_base (
  -- Kurzname des Vereins wie in den anderen Tabellen
  verein      VARCHAR(20) NOT NULL REFERENCES vereine (kurzname),
  -- auf diesen Wert verweisen die anderen Steuer-Tabellen
  nr          INT         NOT NULL default 0,
  -- Bezeichnung der Steuerart
  name        TEXT        NOT NULL,
  -- Prozentsatz max. 4 Stellen hinter dem Komma 
  steuersatz  NUMERIC(8,4) ,
  -- Auf wieviele Stellen wird der Nettobetrag gerundet bevor die Steuer berechnet wird ?
  rundung     INT         NOT NULL default 2
);
CREATE UNIQUE INDEX tax_base_idx ON tax_base (verein,nr);

-- Zuordnungstabelle
CREATE TABLE tax_konten (
  -- Kurzname des Vereins wie in den anderen Tabellen
  verein      VARCHAR(20)   NOT NULL REFERENCES vereine (kurzname),
  -- Referenz zur Basis-Tabelle
  steuersatz  INT           NOT NULL,
  -- Konto-Nummer
  kto         NUMERIC(10,0) NOT NULL
);
CREATE UNIQUE INDEX tax_konten_idx ON tax_konten (verein,kto);

-- Abrechnung(en)
CREATE TABLE tax (
  -- Kurzname des Vereins wie in den anderen Tabellen
  verein      VARCHAR(20)    NOT NULL REFERENCES vereine (kurzname),
  -- Steuerjahr
  jahr        NUMERIC(4,0)   NOT NULL DEFAULT EXTRACT(YEAR FROM CURRENT_DATE),
  -- Abrechnungsdatum
  datum       DATE           NOT NULL DEFAULT current_date,
  -- Steuerart
  art         INT            NOT NULL,
  -- Nettoumsatz
  umsatz      NUMERIC(20,2)  NOT NULL,
  -- steuer
  steuer      NUMERIC(20,2)  NOT NULL
);
CREATE UNIQUE INDEX tax_idx ON tax (verein,jahr,datum,art);

--
-- Grundeinstellung fuer bereits exisiterende Vereine
--
-- Fuer alle Konten "Keine Steuer" erfassen
INSERT INTO tax_base   SELECT kurzname , 0 , 'keine Steuer', '0.00' , '2' FROM vereine;
INSERT INTO tax_konten SELECT verein,    0, kto_nr        FROM bu_konten;
-- Informationen zur Vorsteuer
INSERT INTO tax_base SELECT kurzname , 1 , 'Vorsteuer', '0.00' , '2' FROM vereine;
UPDATE tax_konten SET steuersatz=1 FROM virtual_konto 
                  WHERE art='VORSTEUER' AND konto=kto AND virtual_konto.verein=tax_konten.verein;
